#
# Description: <Method description here>
#
begin
  ## Set the serivce_template_provision_task
  stp_task = $evm.root['service_template_provision_task']
  raise "Failed to set stp_task" if stp_task.nil?  
   
  require 'restclient'
  require 'rexml/document'

  ## UCS credentials pulled from schema
  ucs_user = $evm.object['ucs_user']
  ucs_pw   = $evm.object.decrypt('ucs_pw')
  ## Obtain vars from root
  ucs_mgr = stp_task.options[:ucs_manager]
  rhevh_name = stp_task.options[:rhevh_name]
  blade_dn = stp_task.options[:ucs_blade_dn] 
  ## Obtain vars from input
  action = $evm.inputs['action']

  ## Find any missing values
  missing_fields = ['ucs_user', 'ucs_pw', 'ucs_mgr', 'rhevh_name', 'action', 'blade_dn'].collect do | key |
    key unless eval(key)
  end.compact
  unless missing_fields.empty?
    raise "Missing required variables: [#{missing_fields}]"
  end

  ## Service Profile DN
  rhevh_DN = "org-root/org-Linux/ls-SP_#{rhevh_name}"  
  ## Obtain the system date
  time = Time.new
  system_time = time.strftime "%Y-%m-%dT%H:%M:%S" 
  
  ## Selector statement for the action  
  if action == 'enable'
    status = 'created'
  elsif action == 'disable'
    status = 'deleted'
  end

  ## Object array to enable/disable
  ucs_dn_entries = [ rhevh_DN, blade_dn ]
    
  ## Construct the restclient object to use for connecting to ucs
  ucs_conn = RestClient::Resource.new( "https://#{ucs_mgr}", :ssl_version => 'TLSv1', :verify_ssl => false, :content_type => 'text/xml' )

  ## login to UCS and retrieve the session cookie
  $evm.instantiate('/UnionBank/CiscoUCS/xmlApi/ucsLogin')
  cookie = stp_task.options[:ucs_cookie]
  raise("Failed to get ucs_session cookie") if cookie.nil?
  
  ### Loop through the DN array to enable/disable fault suppression
  ucs_dn_entries.each do |dn_entry|
    
    ## Set the command
    query = "<configConfMo cookie='#{cookie}' dn='#{dn_entry}/fault-suppress-task-maint-server' inHierarchical='false'>
                <inConfig>
                   <faultSuppressTask adminState='untriggered'
                     descr='Ugrading Hypervisor to latest release'
                     dn='#{dn_entry}/fault-suppress-task-maint-server'
                     name='maint-server'
                     policyOwner='local'
                     scheduler=''
                     status='#{status}'
                     suppressPolicyName='default-server-maint'>
                     <trigLocalSched
                        adminState='untriggered'
                        descr=''
                        policyOwner='local'
                        rn='local-sched-default'>
                        <trigLocalAbsWindow
                          concurCap='unlimited'
                          date='#{system_time}'
                          procBreak='none'
                          procCap='unlimited'
                          rn='local-abs-default'
                          timeCap='00:01:30:00.0'>
                        </trigLocalAbsWindow>
                     </trigLocalSched>
                   </faultSuppressTask>
                </inConfig>
             </configConfMo>"

    ## Execute rest call to UCS xml api
#    $evm.log(:info,"PROV_LOG- UCS-[#{rhevh_name}]: query for #{dn_entry}: #{query}")    
    begin
      $evm.log(:info,"PROV_LOG- UCS-[#{rhevh_name}]: #{action} fault suppression on ucs object:#{dn_entry}")
      resp = ucs_conn['/nuova'].post("#{query}")
      xmldoc = REXML::Document.new(resp)
    rescue => e
      raise("[#{rhevh_name}]-Failed to #{action} fault suppression on ucs object via #{ucs_mgr}:[#{e}]")
    end
  end  
  
  exit MIQ_OK

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Caught exception in change_fault_supression:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
ensure
  $evm.instantiate('/UnionBank/ciscoUCS/xmlApi/ucsLogout')
end
