#
# Description: <Method description here>
#
begin
  ## Set the serivce_template_provision_task
  stp_task = $evm.root['service_template_provision_task']
  raise "Failed to set stp_task" if stp_task.nil?  
  
  @debug=stp_task.options[:debug]
  require 'restclient'
  require 'rexml/document'
  
  ## UCS credentials pulled from schema
  ucs_user = $evm.object['ucs_user']
  ucs_pw   = $evm.object.decrypt('ucs_pw')
  ## Obtain vars from root
  ucs_mgr = stp_task.options[:ucs_manager]
  rhevh_name = stp_task.options[:rhevh_name]
  new_sp_template = stp_task.options[:new_ucs_sp_template]
  sp_template = stp_task.options[:ucs_sp_template]
  ## Obtain vars from inputs
  action = $evm.inputs['action']

  ## Find any missing values
  missing_fields = ['ucs_user', 'ucs_pw', 'ucs_mgr', 'rhevh_name', 'action', 'sp_template', 'new_sp_template' ].collect do | key |
    key unless eval(key)
  end.compact
  unless missing_fields.empty?
    raise "Missing required variables: [#{missing_fields}]"
  end  

  ## Set vars based on action passed in  
  if action == 'reset'
    sp_template_new = 'SPT_RHEV_reinitialize_disk'
    sp_template_old = sp_template
  elsif action == 'new'
    sp_template_old = 'SPT_RHEV_reinitialize_disk'
    sp_template_new = new_sp_template 
  end
  
  ## Service Profile DN
  rhevh_DN = "org-root/org-Linux/ls-SP_#{rhevh_name}"
    
  ## Construct the restclient object to use for connecting to ucs
  ucs_conn = RestClient::Resource.new( "https://#{ucs_mgr}", :ssl_version => 'TLSv1', :verify_ssl => false, :content_type => 'text/xml' )

  ## login to UCS and retrieve the session cookie
  $evm.instantiate('/UnionBank/CiscoUCS/xmlApi/ucsLogin')
  cookie = stp_task.options[:ucs_cookie]
  raise("Failed to get ucs_session cookie") if cookie.nil?

  ## Change the service profile template setting #####################
  query = "<configConfMo dn='#{rhevh_DN}' cookie='#{cookie}'>
             <inConfig> 
                <lsServer srcTemplName='#{sp_template_new}' status='modified'/>
             </inConfig>
           </configConfMo>"

  ## Execute rest call to UCS xml api
  begin
    $evm.log(:info,"PROV_LOG- UCS-[#{rhevh_name}]:Changing template from #{sp_template_old} to #{sp_template_new}")
    resp = ucs_conn['/nuova'].post("#{query}")
    xmldoc = REXML::Document.new(resp)
     
  rescue => e
    raise("[#{rhevh_name}]-Failed to change template from #{sp_template_old} to #{sp_template_new} via #{ucs_mgr}:[#{e}]")
  end
  
  exit MIQ_OK

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Caught exception in change_service_profile_template:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
ensure
  $evm.instantiate('/UnionBank/ciscoUCS/xmlApi/ucsLogout')  
end
