#
# Description: <Method description here>
#
begin
  @debug = $evm.root['debug']
  
  require 'restclient'
  require 'rexml/document'

  ## Instantiate local vars
  cookie = nil
  
  ## UCS credentials pulled from schema
  ucs_user = $evm.object['ucs_user']
  ucs_pw   = $evm.object.decrypt('ucs_pw')
  
  ## RHEV cluster pulled from dialog
  cluster_id = $evm.root['dialog_cluster_name'] || ""
  $evm.log(:info,"Cluster ID: #{cluster_id}") if @debug
  
  ## RHEV host name pulled from dialog
  rhevh_name = $evm.root['dialog_rhevh_name'] || nil
  $evm.log(:info,"rhevh_name: #{rhevh_name}") if @debug  

  ## Determine ig cluster_id is null and set default value if it is
  if !cluster_id.eql?nil and !rhevh_name.eql?""

    #get cluster object for the selected cluster
    redhat_cluster = $evm.vmdb('ems_cluster').find_by_id(cluster_id)
    
    ## Obtain UCS manager from cluster tags
    ucs_mgr = redhat_cluster.tags(:ucs_manager).first
    raise "Failed to set ucs_manager from cluster tag" if ucs_mgr.nil?  
    $evm.log(:info, "Setting ucs_mgr: #{ucs_mgr}") if @debug
    
    ## Obtain UCS manager from cluster tags
    environment = redhat_cluster.tags(:environment).first
    raise "Failed to set environment from cluster tag" if environment.nil? 
    env = environment.upcase
    $evm.log(:info, "Setting environment: #{env}") if @debug    
    
    ## Construct the restclient object to use for connecting to ucs
    ucs_conn = RestClient::Resource.new( "https://#{ucs_mgr}", :ssl_version => 'TLSv1', :verify_ssl => false, :content_type => 'text/xml' )

    ## login to UCS and retrieve the session cookie #####################
    $evm.log(:info,"Logging in to UCS: #{ucs_mgr}") if @debug
    begin
      resp = ucs_conn['/nuova'].post(
        "<aaaLogin inName='#{ucs_user}' inPassword='#{ucs_pw}'/>" )
      $evm.log(:info,"UCS Login response: #{resp}") if @debug      
      cookie = REXML::Document.new(resp).root.attributes['outCookie']
    rescue => e
      raise("Failed to login to #{ucs_mgr}:[#{e}]")
    end
    $evm.log(:info,"UCS session cookie: #{cookie}") if @debug
    ####################################################################
    
    ## Obtain the blade DN #############################################
    ## Service Profile DN
    rhevh_DN = "org-root/org-Linux/ls-SP_#{rhevh_name}"
    query = "<configResolveDn cookie='#{cookie}' inHierarchical='false' dn='#{rhevh_DN}'/>"

    ## Execute rest call to UCS xml api
    begin
      resp = ucs_conn['/nuova'].post("#{query}")
      xmldoc = REXML::Document.new(resp)

      ## Get the service profile blade_dn
      blade_dn = xmldoc.elements["configResolveDn/outConfig/lsServer"].attributes["pnDn"]
      $evm.log(:info,"PROV_LOG- UCS-[#{rhevh_name}]: blade_dn = #{blade_dn}")
    
    rescue => e
      raise("[#{rhevh_name}]-Failed to get serviceProfile info via #{ucs_mgr}:[#{e}]")
    end

    # Set an object to be used by another method
    $evm.root['ucs_blade'] = blade_dn
  end

exit MIQ_OK

rescue => err
  $evm.log(:error,"[#{err}]\n#{err.backtrace.join("\n")}")
ensure
  ## logout from UCS
  $evm.log(:info, "Logging out from UCS ...") unless cookie.eql?(nil)
  begin
    ucs_conn['/nuova'].post(
      "<aaaLogout inCookie='#{cookie}'/>" ) unless cookie.eql?(nil)
  rescue => e
    $evm.log(:error, "Failed to logout from #{ucs_mgr}:[#{e}]")
  end
end
