#
# Description: <Method description here>
#
begin
  ## Set the serivce_template_provision_task
  stp_task = $evm.root['service_template_provision_task']
  raise "Failed to set stp_task" if stp_task.nil?  
  
  @debug=stp_task.options[:debug]
  
  require 'restclient'
  require 'rexml/document'

  ## UCS credentials pulled from schema
  ucs_user = $evm.object['ucs_user']
  ucs_pw   = $evm.object.decrypt('ucs_pw')
  
  ## Obtain vars from root
  ucs_mgr = stp_task.options[:ucs_manager]
  rhevh_name = stp_task.options[:rhevh_name]
  
  ## Find any missing values
  missing_fields = ['ucs_user', 'ucs_pw', 'ucs_mgr', 'rhevh_name'].collect do | key |
    key unless eval(key)
  end.compact
  unless missing_fields.empty?
    raise "Missing required variables: [#{missing_fields}]"
  end
  
  ## Service Profile DN
  rhevh_DN = "org-root/org-Linux/ls-SP_#{rhevh_name}"
    
  ## Construct the restclient object to use for connecting to ucs
  ucs_conn = RestClient::Resource.new( "https://#{ucs_mgr}", :ssl_version => 'TLSv1', :verify_ssl => false, :content_type => 'text/xml' )

  ## login to UCS and retrieve the session cookie
  $evm.instantiate('/UnionBank/CiscoUCS/xmlApi/ucsLogin')
  cookie = stp_task.options[:ucs_cookie]
  raise("Failed to get ucs_session cookie") if cookie.nil?
  
  ## Obtain Service Profile mac address ############################################################
  query = "<configResolveDn cookie='#{cookie}' inHierarchical='true' dn='#{rhevh_DN}/ether-eth0'/>"

  ## Execute rest call to UCS xml api
  begin
    resp = ucs_conn['/nuova'].post("#{query}")
    xmldoc = REXML::Document.new(resp)
      
    ## Parse the xmldoc for mac_address
    rhevh_macaddress = xmldoc.elements["configResolveDn/outConfig/vnicEther"].attributes["addr"]
    $evm.log(:info,"PROV_LOG- UCS-[#{rhevh_name}]: rhvh_macaddress= #{rhevh_macaddress}")
    
  rescue => e
    raise("[#{rhevh_name}]-Failed to get mac_address for #{rhevh_name} via #{ucs_mgr}:[#{e}]")
  end

  ## Set an object to be used by another method
  stp_task.set_option(:rhevh_macaddress, rhevh_macaddress)
  
  exit MIQ_OK

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Caught exception in get_ucs_macaddress:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
ensure
  $evm.instantiate('/UnionBank/ciscoUCS/xmlApi/ucsLogout')
end
