#
# Description:
#  This method will pull templates from UCS that have been filtered based on some criteria
#   Filtered by environment selected in dialog
#   Filtered by serviceProfile or blade selected in dialog
#
begin
  @debug = $evm.root['debug']
  
  require 'restclient'
  require 'rexml/document'

  ## Instantiate local vars
  templates = []
  cookie = nil
  
  ## UCS credentials pulled from schema
  ucs_user = $evm.object['ucs_user']
  ucs_pw   = $evm.object.decrypt('ucs_pw')
  
  ## RHEV cluster pulled from dialog
  cluster_id = $evm.root['dialog_cluster_name'] || nil
  $evm.log(:info,"Cluster ID: #{cluster_id}") if @debug

  ## RHEV blade pulled from dialog/other method
  ucs_blade = $evm.root['ucs_blade'] || nil
  
  
  ## Determine ig cluster_id is null and set default value if it is
  if !cluster_id.eql? nil and !ucs_blade.eql?nil

    #get cluster object for the selected cluster
    redhat_cluster = $evm.vmdb('ems_cluster').find_by_id(cluster_id)
    
    ## Obtain UCS manager from cluster tags
    ucs_mgr = redhat_cluster.tags(:ucs_manager).first
    raise "Failed to set ucs_manager from cluster tag" if ucs_mgr.nil?  
    $evm.log(:info, "Setting ucs_mgr: #{ucs_mgr}") if @debug
    
    ## Obtain UCS manager from cluster tags
    environment = redhat_cluster.tags(:environment).first
    raise "Failed to set environment from cluster tag" if environment.nil? 
    env = environment.upcase
    $evm.log(:info, "Setting environment: #{env}") if @debug    
    
    ## Construct the restclient object to use for connecting to ucs
    ucs_conn = RestClient::Resource.new( "https://#{ucs_mgr}", :ssl_version => 'TLSv1', :verify_ssl => false, :content_type => 'text/xml' )

    ## login to UCS and retrieve the session cookie
    $evm.log(:info,"Logging in to UCS: #{ucs_mgr}") if @debug
    begin
      resp = ucs_conn['/nuova'].post(
        "<aaaLogin inName='#{ucs_user}' inPassword='#{ucs_pw}'/>" )
      $evm.log(:info,"UCS Login response: #{resp}") if @debug      
      cookie = REXML::Document.new(resp).root.attributes['outCookie']
    rescue => e
      raise("Failed to login to #{ucs_mgr}:[#{e}]")
    end
    $evm.log(:info,"UCS session cookie: #{cookie}") if @debug

    ### Query UCS for the templates #########################################
    ## Determine filter based on the blade/environment
    blade_number = ucs_blade[-1, 1].to_i
    if blade_number.even?
      filter = "SPT_RVH_#{env}_B(\\d)?$"
    else
      filter = "SPT_RVH_#{env}_A(\\d)?$"
    end
    
    ## Gather servics profile templates
    query = "
     <configResolveClass
       cookie='#{cookie}'
       inHierarchical='false'
       classId='lsServer'>
       <inFilter>
         <wcard class='lsServer'
            property='name' value='#{filter}'
         />
       </inFilter>
     </configResolveClass>"

    ## Execute rest call to UCS xml api
    begin
      resp = ucs_conn['/nuova'].post("#{query}")
      xmldoc = REXML::Document.new(resp)
      
      ## Parse the xmldoc for computeBlades and load them into hash 
      xmldoc.elements.each("configResolveClass/outConfigs/lsServer") { |element|
        templates.push("#{element.attributes['name']}")
        $evm.log(:info, "template= #{element.attributes['name']}") if @debug
      }
    rescue => e
      raise("Failed to query ucs #{ucs_mgr} for service profile templates:[#{e}]")
    end
    ############################################################################

  # Set an object to be used by another method
  $evm.root['ucs_template'] = templates.last
  end

exit MIQ_OK

rescue => err
  $evm.log(:error,"[#{err}]\n#{err.backtrace.join("\n")}")
ensure
  ## logout from UCS
  $evm.log(:info, "Logging out from UCS ...") unless cookie.eql?(nil)
  begin
    ucs_conn['/nuova'].post(
      "<aaaLogout inCookie='#{cookie}'/>" ) unless cookie.eql?(nil)
  rescue => e
    $evm.log(:error, "Failed to logout from #{ucs_mgr}:[#{e}]")
  end
end
