#
# Description: <Method description here>
#
begin
  ## Set the serivce_template_provision_task
  stp_task = $evm.root['service_template_provision_task']
  raise "Failed to set stp_task" if stp_task.nil?  
  
  @debug=stp_task.options[:debug]
  require 'restclient'
  require 'rexml/document'
  
  ## UCS credentials pulled from schema
  ucs_user = $evm.object['ucs_user']
  ucs_pw   = $evm.object.decrypt('ucs_pw')
  ## Obtain vars from root
  ucs_mgr = stp_task.options[:ucs_manager]
  rhevh_name = stp_task.options[:rhevh_name]
  blade_dn = stp_task.options[:ucs_blade_dn]
  
  count = stp_task.options[:wait_count] || 0
  
  ## Obtain vars from input
  action = $evm.inputs['action']

  ## Find any missing values
  missing_fields = ['ucs_user', 'ucs_pw', 'ucs_mgr', 'rhevh_name', 'action', 'blade_dn', 'count'].collect do | key |
    key unless eval(key)
  end.compact
  unless missing_fields.empty?
    raise "Missing required variables: [#{missing_fields}]"
  end  
  
  ## Hardcoded vars
  search_success = false
  max_count = 30
  
  ## validate based on the action selecte
  if action == 'changed_template' or action == 'associated'
    ## Used to validate that the template change is complete
    rhevh_DN = "org-root/org-Linux/ls-SP_#{rhevh_name}"
    items = [{ :name => 'configState', :value => 'applied'},{ :name => 'assocState', :value => 'associated' }]
    objectType = 'lsServer'
  elsif action == 'disassociated'
    ## Used to validate that the service profile was disassociated from the blade
    rhevh_DN = blade_dn
    items = [{ :name => 'association', :value => 'none'},{ :name => 'availability', :value => 'available' }]
    objectType = 'computeBlade'
  elsif action == 'power-down'
    rhevh_DN = "org-root/org-Linux/ls-SP_#{rhevh_name}"
    items = [{:name => 'operState', :value => 'power-off'}]
    objectType = 'lsServer'
  end
      
  ## Construct the restclient object to use for connecting to ucs
  ucs_conn = RestClient::Resource.new( "https://#{ucs_mgr}", :ssl_version => 'TLSv1', :verify_ssl => false, :content_type => 'text/xml' )

  ## login to UCS and retrieve the session cookie
  $evm.instantiate('/UnionBank/CiscoUCS/xmlApi/ucsLogin')
  cookie = stp_task.options[:ucs_cookie]
  raise("Failed to get ucs_session cookie") if cookie.nil?

  ## Set the command
  query = "<configResolveDn cookie='#{cookie}' dn='#{rhevh_DN}' inHierarchical='false' />"

  ## Determine if the max count has been reached to raise an exception
  if count == max_count
    raise "Timed out waiting for #{rhevh_DN} items to match expected values:'#{items}'"
  else    
    begin
      ## Executes the xml Query to search for the objects that need validating
      $evm.log(:info,"PROV_LOG- UCS-[#{rhevh_name}]: Validating #{rhevh_DN} #{action} for Items:#{items}")
      $evm.log(:info,"PROV_LOG- UCS-[#{rhevh_name}]: Count is #{count} of #{max_count}")        
      resp = ucs_conn['/nuova'].post("#{query}")
      xmldoc = REXML::Document.new(resp)
    
      ## Loop through the items that need validating
      items.each do |item|
        $evm.log(:info,"PROV_LOG_DEBUG- UCS-[#{rhevh_name}]: Working on #{item[:name]} = #{item[:value]}" ) if @debug   
        ## Grab the actual value of the element from the XML
        item_value = xmldoc.elements["configResolveDn/outConfig/#{objectType}"].attributes["#{item[:name]}"]
        $evm.log(:info,"PROV_LOG_DEBUG- UCS-[#{rhevh_name}]: Object #{item[:name]} = #{item_value}" ) if @debug        
         
        ## Determine if they equal what we are looking for
        if item_value != item[:value]
          ## If they aren't equal break out of the loop and set the instance to retry
          $evm.log(:info,"PROV_LOG_DEBUG- UCS-[#{rhevh_name}]: Object #{item[:name]}: #{item_value} and not #{item[:value]}...waiting") if @debug
          search_success = false
          $evm.root['ae_result'] = 'retry'
          $evm.root['ae_retry_interval'] = '60.seconds'
          break
        else
          ## If they are equal set search_success to true
          $evm.log(:info,"PROV_LOG_DEBUG- UCS-[#{rhevh_name}]: Object #{item[:name]}: #{item[:value]} matches #{item_value}") if @debug
          search_success = true
        end
      end
    rescue => e
       raise("[#{rhevh_name}]-Failed to validate #{rhevh_DN} #{action} for items:#{items} via #{ucs_mgr}:[#{e}]")
    end
  end

## determine if search_success is true, and if it is then print to the log a success statement
## If it isn't update the count for the next iteration
if search_success == true
  $evm.log(:info,"PROV_LOG- UCS-[#{rhevh_name}]: Successfully Validated #{rhevh_DN} #{action} for Items:#{items}")
else
  ## Set the new count for the next iteration
  count += 1
  stp_task.set_option(:wait_count, count)
end

exit MIQ_OK

rescue => err
  $evm.root['ae_result'] = 'error'
$evm.root['ae_reason'] = "Caught exception in validate_ucs_object_status:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
ensure
  $evm.instantiate('/UnionBank/ciscoUCS/xmlApi/ucsLogout')
end
