#
# Description: <Method description here>
#
begin
  require 'xmlrpc/client'
  
  def delete_system_by_property(server, token, key, value)
    begin
      system_names = server.call('find_system', {key=>value})
      system_names.each do | system_name |
        $evm.log('warn', "PROV_LOG- Deleting duplicate system: [#{system_name}]")
        server.call('remove_system', system_name, token, false)
      end
    rescue => e
      raise "Failed to delete existing cobbler system with #{key}=#{value}:[#{e}]"
    end
  end

#####################################################################################
### MAIN ############################################################################
#####################################################################################
  
  ## Set the serivce_template_provision_task
  stp_task = $evm.root['service_template_provision_task']
  raise "Failed to set stp_task" if stp_task.nil?  
  
  @debug=stp_task.options[:debug]
  
  #Set variables from $emv.object
  cobbler_username = $evm.object['cobbler_username']
  cobbler_password = $evm.object.decrypt('cobbler_password')

  ## Set variables from root
  infoblox_response = stp_task.options[:infoblox_response]
  cobbler_profile = stp_task.options[:os_version]
  cobbler_hostname = stp_task.options[:cobbler_host]
  rhevm_name = stp_task.options[:rhevm_name]
  datacenter = stp_task.options[:data_center]
  ucs_manager = stp_task.options[:ucs_manager]
  
  ## Find any missing values
  missing_fields = [
    'infoblox_response', 'cobbler_hostname', 'cobbler_username', 'cobbler_password',
    'cobbler_profile', 'rhevm_name', 'datacenter', 'ucs_manager'].collect do | key |
      key unless eval(key)
  end.compact
  unless missing_fields.empty?
    raise "Missing required variables: [#{missing_fields}]"
  end
  
  ## Set local vars
  admin_hash_pw = '$1$RZ12kTfP$Ki0zeNThu5WN/fzsaHbiD0'
  root_hash_pw = '$1$RZ12kTfP$Ki0zeNThu5WN/fzsaHbiD0'
  dc = datacenter.slice(0, 2)   
  syslog_server = "#{dc}-rhv-syslog.unionbank.com"

  ##Set the kdump_nfs var based on 
  
  #case "#{ucs_manager}"
  #  when "chucspte002"
  #   kdump_nfs = 'chnetapp30nfs-06:/ch30_06_nfs_rhev_kdump_pte_v02'
  #  when "chucspte102"
  #   kdump_nfs = 'chnetapp30nfsdmz-08:/ch30_08_dmz_nfs_rhev_kdump_pte_v02'
  #  when "chucsprd002"
  #   kdump_nfs = 'chnetapp31nfs-01:/ch31_01_nfs_rhev_kdump_prd_v01'
  #  when "chucsprd102"
  #   kdump_nfs = 'chnetapp31nfsdmz-02:/ch31_02_dmz_nfs_rhev_kdump_prd_v02'
  #  when "mpucsprd002"
  #   kdump_nfs = 'mpnetapp31nfs-01:/mp31_01_nfs_rhev_kdump_prd_v01'
  #  when "mpucsprd102"
  #   kdump_nfs = 'mpnetapp31nfsdmz-02:/mp31_02_dmz_nfs_rhev_kdump_prd_v02'
  #else
  #  raise "Could not determine the kdump_nfs setting for hypervisor:[#{fqdn}]"
  #end
  
  ## Set more variables from the first entry in the infoblox_response
  primary_adapter = infoblox_response[0]
  adapter = primary_adapter[:adapter]
  fqdn = primary_adapter[:fqdn]
  gateway = primary_adapter[:gateway]
  mac_address = primary_adapter[:mac]
  netmask = primary_adapter[:netmask]
  ip_address = primary_adapter[:ip]

  ## Begin the cobbler registration workflow
  $evm.log(:info, "PROV_LOG- Cobbler/register_hypervisor - Adding new hypervisor #{fqdn} to Cobbler")    
  
  kopts = "hostname=#{fqdn} ksdevice=#{adapter} ip=#{ip_address} netmask=#{netmask} gateway=#{gateway} management_server=#{rhevm_name} "
  #kopts += "adminpw=#{admin_hash_pw} syslog=#{syslog_server} rhevm_admin_password=#{root_hash_pw} kdump_nfs=#{kdump_nfs}"
  kopts += "adminpw=#{admin_hash_pw} syslog=#{syslog_server} rhevm_admin_password=#{root_hash_pw}"
  
  ## Debug statements
  $evm.log(:info, "PROV_LOG_DEBUG- [adapter]: #{adapter}") if @debug 
  $evm.log(:info, "PROV_LOG_DEBUG- [fqdn]: #{fqdn}") if @debug 
  $evm.log(:info, "PROV_LOG_DEBUG- [ip_address]: #{ip_address}") if @debug   
  $evm.log(:info, "PROV_LOG_DEBUG- [gateway]: #{gateway}") if @debug 
  $evm.log(:info, "PROV_LOG_DEBUG- [mac_address]: #{mac_address}") if @debug 
  $evm.log(:info, "PROV_LOG_DEBUG- [kopts]: #{kopts}") if @debug 
  
  conn_args = { :host => cobbler_hostname, :path => '/cobbler_api', :port => '443', :use_ssl => true, }  
  server = XMLRPC::Client.new_from_hash(conn_args)
  token  = nil
  begin
    token = server.call('login', cobbler_username, cobbler_password)
  rescue => e
    raise "Failed to connect to cobbler #{cobbler_hostname}:[#{e}]"
  end

  ## Delete any existing systems w/ the same hostname / mac address
  delete_system_by_property(server, token, 'hostname', fqdn )
  delete_system_by_property(server, token, 'mac', mac_address )  
  ## Delete any existing systems w/ the same Ipaddress
  delete_system_by_property(server, token, 'ip', ip_address )
  
  ## Create the new system
  begin
    system_id = server.call('new_system', token)
    server.call('modify_system', system_id, 'name', fqdn, token)
    server.call('modify_system', system_id, 'hostname', fqdn, token)
    
    ## Add the primary interface
    $evm.log(:info, "PROV_LOG_DEBUG- Adding interface to cobbler system: adapter:[#{adapter}],mac:[#{mac_address}],ip:[#{ip_address}],subnet-mask:[#{netmask}") if @debug
      
    ## Execute the server call for each interface
    server.call('modify_system', system_id, 'modify_interface', {
      "macaddress-#{adapter}"=>mac_address,
      "ipaddress-#{adapter}"=>ip_address,
      "subnet-#{adapter}"=>netmask,
      "static-#{adapter}"=>'true'}, token)
 
    server.call('modify_system', system_id, 'gateway', gateway, token)
    server.call('modify_system', system_id, 'profile', cobbler_profile, token)
    server.call('modify_system', system_id, 'kernel_options', kopts, token)
    server.call('save_system', system_id, token)
    server.call('sync', token)
 rescue => e
    raise "Registration failed with error:[#{e}]"
 end
 exit MIQ_OK

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Failed to register system with Cobbler:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
end
