#
# Description: <Method description here>
#
begin
  require 'xmlrpc/client'
  
  def delete_system_by_property(server, token, key, value)
    begin
      system_names = server.call('find_system', {key=>value})
      system_names.each do | system_name |
        $evm.log('warn', "PROV_LOG- Deleting duplicate system in cobbler: [#{system_name}]")
        server.call('remove_system', system_name, token, false)
      end
    rescue => e
      raise "Failed to delete existing cobbler system with #{key}=#{value}:[#{e}]"
    end
  end

#####################################################################################
### MAIN ############################################################################
#####################################################################################
  
  ## Set the provision and vm objects
  prov = $evm.root['miq_provision']
  @debug = prov.options[:debug]
  vm = prov.destination
  
  #Set variables from $emv.object
  cobbler_username = $evm.object['cobbler_username']
  cobbler_password = $evm.object.decrypt('cobbler_password')
  #set callback url in ks_meta
  callback_url  = prov.object_send(:post_install_callback_url) if prov
  ks_meta = {}
  ks_meta["callback_url"] = "#{callback_url}"
  $evm.log("info", "PROV_LOG_DEBUG- ks_meta : #{ks_meta.inspect}") if @debug
  
  ## Set variables from prov 
  infoblox_response = prov.options[:infoblox_response] if prov
  cobbler_profile = prov.options[:os_version] if prov
  cobbler_hostname = prov.options[:cobbler_host] if prov

  ## Find any missing values
  missing_fields = [
    'infoblox_response', 'cobbler_hostname', 'cobbler_username', 'cobbler_password',
    'cobbler_profile', 'ks_meta'].collect do | key |
      key unless eval(key)
  end.compact
  unless missing_fields.empty?
    raise "Missing required variables: [#{missing_fields}]"
  end

  $evm.log(:info, "PROV_LOG_DEBUG- Cobbler/register_system - Adding new system to Cobbler") if @debug

 ## Set more variables from the first entry in the infoblox_response
 primary_adapter = infoblox_response[0]
 vm_fqdn = primary_adapter[:fqdn]
 vm_gateway = primary_adapter[:gateway]
 vm_macaddress = primary_adapter[:mac]

 ## Debug statements
 $evm.log(:info, "PROV_LOG_DEBUG- [vm_fqdn]: #{vm_fqdn}") if @debug 
 $evm.log(:info, "PROV_LOG_DEBUG- [vm_gateway]: #{vm_gateway}") if @debug 
 $evm.log(:info, "PROV_LOG_DEBUG- [vm_macaddress]: #{vm_macaddress}") if @debug 

 conn_args = { :host => cobbler_hostname, :path => '/cobbler_api', :port => '443', :use_ssl => true, }  
 server = XMLRPC::Client.new_from_hash(conn_args)
 token  = nil
 begin
   token = server.call('login', cobbler_username, cobbler_password)
 rescue => e
   raise "Failed to connect to cobbler #{cobbler_hostname}:[#{e}]"
 end

 ## Delete any existing systems w/ the same hostname / mac address
 delete_system_by_property(server, token, 'hostname', vm_fqdn )
 delete_system_by_property(server, token, 'mac', vm_macaddress )  

 ## Delete any existing systems w/ the same IP Address
 infoblox_response.each do |interface|
      ## Set local vars in the loop
      ipadd = interface[:ip]
      
      ## Execute the server call for each interface
      delete_system_by_property(server, token, 'ip', ipadd )
 end
  
 ## Create the new system
 begin
    system_id = server.call('new_system', token)
    server.call('modify_system', system_id, 'name', vm_fqdn, token)
    server.call('modify_system', system_id, 'hostname', vm_fqdn, token)
    
    ## Add the interfaces passed in from infoblox
    infoblox_response.each do |interface|
      ## Set local vars in the loop
      adapter = interface[:adapter]
      mac_address = interface[:mac]
      ip_address = interface[:ip]
      netmask = interface[:netmask]

      ## Debug statements
      $evm.log(:info, "PROV_LOG_DEBUG- Adding interface to cobbler system: adapter:[#{adapter}],mac:[#{mac_address}],ip:[#{ip_address}],subnet-mask:[#{netmask}") if @debug
      
      ## Execute the server call for each interface
      server.call('modify_system', system_id, 'modify_interface', {
        "macaddress-#{adapter}"=>mac_address,
        "ipaddress-#{adapter}"=>ip_address,
        "subnet-#{adapter}"=>netmask,
        "static-#{adapter}"=>'true'}, token)
    end
 
    server.call('modify_system', system_id, 'gateway', vm_gateway, token)
    server.call('modify_system', system_id, 'profile', cobbler_profile, token)
    server.call('modify_system', system_id, 'ks_meta', ks_meta, token)
    server.call('save_system', system_id, token)
    server.call('sync', token)
   
   $evm.log(:info, "PROV_LOG- Succesfully added interface to cobbler system")
 
 rescue => e
    raise "Failed to register system with Cobbler:[#{e}]"
 end
 exit MIQ_OK

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Failed to register system with Cobbler:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
  #exit MIQ_ABORT
end
