#
# Description: This method check if IP exists in infoblox
#

require 'restclient'
require 'rexml/document'

begin
####### METHOD INFOBLOX_HOST_REQUEST ##############################################
## registers dns name to infoblox and returns the IP,gateway,and fqdn
  def infoblox_host_request(blox_hostname, blox_script, params)
    response = nil
   begin
     input = "https://#{blox_hostname}:444/ub/cgi-bin/#{blox_script}?#{params.collect{|k| k.join("=")}.join("&")}"
    $evm.log(:info, "Infoblox input: #{input}")
    response = RestClient::Request.execute(:url => "#{input}", :method => :get, :verify_ssl => false )
    $evm.log(:info, "Infoblox response: [#{response}]")
   rescue => e
  raise "Error registering/querying dns name in infoblox:#{e.class}:[#{e}]"
   end

   ## Parse the xml response
   output = {}
   xmldoc = REXML::Document.new(response)
   xmldoc.elements.each("Network/IPAddress"){ |element| output['ipaddress'] = element.text }

  return output, response
  end

########################################################################################
#### METHOD MAIN #######################################################################
########################################################################################

##Set vars required for infoblox from the class
blox_hostname = $evm.object['blox_hostname']
blox_username = $evm.object['blox_username']
blox_password = $evm.object.decrypt('blox_password')


#user details
userid =$evm.root['user'].userid.split("@").first
username =$evm.root['user'].name
user = "#{userid}(#{username})"

blox_script = 'UB-Query-Host-Information.pl'

## Set defaults for infoblox params
params = {
  'platform'  => 'RHEV',
  'username' => "#{blox_username}",
  'password' => "#{blox_password}",
  'user'     => "#{user}",
}

##Localize vars
fqdn = $evm.object['dialog_vm_name'] || ''
if ( fqdn != '' && fqdn !~ /None/ && !fqdn.nil? )
 fqdn += ".unionbank.com"

 ## reset vars for each loop
 ip_info = {}
 ip_error = ""
    
 ##Set additional params for infoblox
 params['fqdn'] = "#{fqdn}"
      

 ## Obtain information from infoblox
 ip_info,ip_error = infoblox_host_request(blox_hostname, blox_script, params)
    
 ## Error checking to ensure infoblox returned info
 if ip_info.empty?
   str = ip_error.gsub("'","").strip
    ip = "IP does not exist for this VM" 
 else
   ip = ip_info['ipaddress']
   ip = "IP already exists for this VM (#{ip})"
 end
  
  list_values = {
    'data_type' => :string,
    'required'  => false,
    'value'     => ip,
    'display'	=> :show
  }
  list_values.each { |key, value| $evm.object[key] = value }

end 

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.log('error', "Caught exception in check_ip:#{err.class}:#{err}")
end 
 
