#
# Description: This method check if IP exists in infoblox for all vlans
#

require 'restclient'
require 'rexml/document'

begin
####### METHOD INFOBLOX_HOST_REQUEST ##############################################
## registers dns name to infoblox and returns the IP,gateway,and fqdn
  def infoblox_host_request(blox_hostname, blox_script, params)
    response = nil
   begin
     input = "https://#{blox_hostname}:444/ub/cgi-bin/#{blox_script}?#{params.collect{|k| k.join("=")}.join("&")}"
    $evm.log(:info, "PROV_LOG- Infoblox input: #{input}")
    response = RestClient::Request.execute(:url => "#{input}", :method => :get, :verify_ssl => false )
    $evm.log(:info, "PROV_LOG- Infoblox response: [#{response}]")
   rescue => e
  raise "Error registering/querying dns name in infoblox:#{e.class}:[#{e}]"
   end

   ## Parse the xml response
   output = {}
   xmldoc = REXML::Document.new(response)
   xmldoc.elements.each("Network/IPAddress"){ |element| output['ipaddress'] = element.text }

  return output, response
  end

########################################################################################
#### METHOD MAIN #######################################################################
########################################################################################

##Set vars required for infoblox from the class
blox_hostname = $evm.object['blox_hostname']
blox_username = $evm.object['blox_username']
blox_password = $evm.object.decrypt('blox_password')


#user details
userid =$evm.root['user'].userid.split("@").first
username =$evm.root['user'].name
user = "#{userid}(#{username})"

blox_script = 'UB-Query-Host-Information.pl'

## Set defaults for infoblox params
params = {
  'platform'  => 'RHEV',
  'username' => "#{blox_username}",
  'password' => "#{blox_password}",
  'user'     => "#{user}",
}

prov = $evm.root['miq_provision']
vm_name = prov.options[:vm_name]
has_tsm = prov.options[:has_tsm] || ''
has_nfs = prov.options[:has_nfs] || ''
ip_exists = prov.options[:ips_registered_in_infoblox]

  ## check ip for primary vlan
raise_err =0  
fqdn_pri = vm_name || ''
fqdn_pri += ".unionbank.com"
fqdn_tsm = "#{vm_name}-tsm.unionbank.com"  
fqdn_nfs = "#{vm_name}-nfs.unionbank.com"  
fqdn_arr = ["#{fqdn_pri}"]
if(has_tsm != '')
  fqdn_arr << fqdn_tsm
end
if(has_nfs !='')
  fqdn_arr << fqdn_nfs
end
$evm.log(:info, "PROV_LOG- has nfs: #{has_nfs}]")
  $evm.log(:info, "PROV_LOG- has tsm: #{has_tsm}]")
#if ip_exists == 'f'
#  str = "'IP already exists in infoblox' is not checked."
#else
#  str = "'IP already exists in infoblox' is checked."
#end 
str =""  
fqdn_arr.each do |fqdn|  
  $evm.log(:info, "PROV_LOG- fqdn: #{fqdn}]")
  ## reset vars for each loop
  ip_info = {}
  ip_error = ""

  ##Set additional params for infoblox
  params['fqdn'] = "#{fqdn}"

  ## Obtain information from infoblox if IP exists is checked
  ip_info,ip_error = infoblox_host_request(blox_hostname, blox_script, params)

  ip_flag = 'f'
  ## Error checking to ensure infoblox returned info
  if ip_info.empty?
     ip_flag = 'f'
  else
    ip = ip_info['ipaddress']
    ip_flag = 't'
  end
  fqdn = fqdn.gsub(/\.unionbank\.com/,'')
  if ip_flag == 't'
  	str += " IP already exist for #{fqdn}."
  else
	str += " IP does not exist for #{fqdn}."
  end
  ##raise error if ip_exists is checked but no ip exists and vice-versa
  if(ip_exists == 'f' && ip_flag == 't')
    raise_err = 1 
  end
  if(ip_exists == 't' && ip_flag == 'f')
    raise_err = 1
  end
 $evm.log(:info, "PROV_LOG- str: #{str}]")
end
if raise_err == 1
  raise "#{str}"
else
  exit MIQ_OK
end

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Caught exception in check_ip_all: #{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
end 
 

