#
# Description: This method provisions IP's and returns infoblox_response
# along with the supporting information
#
require 'restclient'
require 'rexml/document'

begin

####### METHOD INFOBLOX_HOST_REQUEST ##############################################
## registers dns name to infoblox and returns the IP,gateway,and fqdn
  def infoblox_host_request(blox_hostname, blox_script, params)
    $evm.log(:info, "PROV_LOG- Infoblox request: params[#{params.each_with_object({}) { |(k,v), hash| hash[k] = /password/.match(k) ? "******" : v }}]")
    response = nil
   begin
     input = "https://#{blox_hostname}:444/ub/cgi-bin/#{blox_script}?#{params.collect{|k| k.join("=")}.join("&")}"
    $evm.log(:info, "PROV_LOG_DEBUG- Infoblox input: #{input}") if @debug
    response = RestClient::Request.execute(:url => "#{input}", :method => :get, :verify_ssl => false )
    $evm.log(:info, "PROV_LOG- Infoblox response: [#{response}]")
   rescue => e
  raise "Error registering/querying dns name in infoblox:#{e.class}:[#{e}]"
   end

   ## Parse the xml response
   output = {}
   xmldoc = REXML::Document.new(response)
   xmldoc.elements.each("Network/IPAddress"){ |element| output['ipaddress'] = element.text }
   xmldoc.elements.each("Network/DefaultGateway"){ |element| output['gateway'] = element.text }
   xmldoc.elements.each("Network/CIDR"){ |element| output['subnet'] = element.text }

  return output, response 
  end

########################################################################################
#### METHOD MAIN #######################################################################
########################################################################################

## Set the serivce_template_provision_task
stp_task = $evm.root['service_template_provision_task']
raise "Failed to set stp_task" if stp_task.nil?  
  
@debug=stp_task.options[:debug]

##Set vars required for infoblox from the class
blox_hostname = $evm.object['blox_hostname']
blox_username = $evm.object['blox_username']
blox_password = $evm.object.decrypt('blox_password')

## Determine datacenter
datacenter = stp_task.options[:data_center]
dc = datacenter.slice(0, 2)
env = stp_task.options[:environment]
nl = stp_task.options[:network_location]

#user details
userid =$evm.root['user'].userid.split("@").first
username =$evm.root['user'].name
user = "#{userid}(#{username})"

#determine if ips already provisioned
ips_registered = stp_task.options[:ips_registered_in_infoblox] || 'f'

$evm.log(:info, "PROV_LOG_DEBUG- [ips_registered]:#{ips_registered}]" ) if @debug

#determine blox script
if ips_registered != 'f'
  blox_script = 'UB-Query-Host-Information.pl'
else
  blox_script = 'UB-Allocate-Host.pl'
end

## Set defaults for infoblox params
params = {
  'platform'  => 'RHEV',
  'username' => "#{blox_username}",
  'password' => "#{blox_password}",
  'user'     => "#{user}",
  'tagname'  => 'datacenter,rvm_env,rvm_vlanname,network_location'
}

## Add Networks
## Localalize object vars
network_info = stp_task.options[:network_info]
$evm.log(:info, "PROV_LOG_DEBUG- [network_info]:#{network_info.inspect}]" ) if @debug
  
## Set defaults
infoblox_response = []
nfs_network_info = {}
  
## Set the primary network adapter information
$evm.log(:info, "PROV_LOG_DEBUG- Looping through network_info array" ) if @debug
network_info.each do |network|
    
  ##Localize vars
  type = network[:type]
  fqdn = network[:fqdn]
  adapter = network[:adapter_name]
  vlan = network[:network_name]
    
  ## reset vars for each loop
  ip_info = {}
  ip_hash = {}
  mac = nil
  
  ##Set additional params for infoblox   
  params['fqdn'] = "#{fqdn}"  
  params['tagvalue'] = "#{dc},#{env},#{vlan},#{nl}"
      
  ## Obtain information from infoblox
  ip_info,ip_error = infoblox_host_request(blox_hostname, blox_script, params)
    
  ## Error checking to ensure infoblox returned info
  if ip_info.empty?
    error = ip_error.gsub("'","").strip
    raise "#{error} : Vlan: #{vlan} : Adapter:#{adapter}"
  end
      
  ## Set local vars from infoblox response
  ip = ip_info['ipaddress']
  subnet = ip_info['subnet']
  gateway = ip_info['gateway']

  ## Obtain the netmask
  case subnet
  when /\/21/
    netmask = "255.255.248.0"      
  when /\/22/
    netmask = "255.255.252.0"  
  when /\/23/
    netmask = "255.255.254.0"  
  when /\/24/
    netmask = "255.255.255.0"
  when /\/25/
    netmask = "255.255.255.128"
  else
    raise "Failed to find proper netmask for network: #{fqdn}"
  end  
  
  ## Debug statements
  $evm.log(:info, "PROV_LOG_DEBUG- Working on fqdn:[#{fqdn}], adapter:[#{adapter}], ip:[#{ip}], subnet:[#{subnet}], gateway:[#{gateway}]" ) if @debug      

  ## Set different root vars based on the network type
  if type == 'primary'
    ## Only set the mac address for the primary network
    mac = stp_task.options[:rhevh_macaddress]
    raise "mac_address for #{fqdn} is null" if mac.blank?
    
    ## Add the network info to another array
    ip_hash = {:fqdn => fqdn, :ip => ip, :netmask => netmask, :gateway => gateway, :adapter => adapter, :mac => mac }

    $evm.log(:info, "PROV_LOG_DEBUG- Adding ip_hash into infoblox_response:[#{ip_hash.inspect}]" ) if @debug
    infoblox_response << ip_hash    

    ## Set the root var for infoblox_response
    stp_task.set_option(:infoblox_response, infoblox_response)
    $evm.log(:info, "Set infoblox_response:[#{infoblox_response.inspect}]" )    
    
  elsif type == 'nfs'
    ## Add the network info to another array
    ip_hash = {:fqdn => fqdn, :ip => ip, :netmask => netmask, :gateway => gateway, :adapter => adapter }

    $evm.log(:info, "PROV_LOG_DEBUG- Adding ip_hash into nfs_network_info:[#{ip_hash.inspect}]" ) if @debug
    nfs_network_info = ip_hash
    
    ## Set the root var for infoblox_response    
    stp_task.set_option(:nfs_network_info, nfs_network_info)
    $evm.log(:info, "PROV_LOG- Set nfs_network_info:[#{nfs_network_info.inspect}]" )  
  else
    raise "Could not determine network type for network: #{network.inspect}"
  end
end

exit MIQ_OK
  
rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Caught exception in porvision_hypervisor_ips: #{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
end 
