#
# Description: This method provisions IP's and returns infoblox_response
# along with the supporting information
#
require 'restclient'
require 'rexml/document'

begin
prov = $evm.root['miq_provision']
@debug = prov.options[:debug]

####### METHOD INFOBLOX_HOST_REQUEST ##############################################
## registers dns name to infoblox and returns the IP,gateway,and fqdn
  def infoblox_host_request(blox_hostname, blox_script, params)
    $evm.log(:info, "PROV_LOG_DEBUG- Infoblox request: params[#{params.each_with_object({}) { |(k,v), hash| hash[k] = /password/.match(k) ? "******" : v }}]") if @debug
    response = nil
   begin
     input = "https://#{blox_hostname}:444/ub/cgi-bin/#{blox_script}?#{params.collect{|k| k.join("=")}.join("&")}"
    $evm.log(:info, "PROV_LOG_DEBUG- Infoblox input: #{input}") if @debug
    response = RestClient::Request.execute(:url => "#{input}", :method => :get, :verify_ssl => false )
  $evm.log(:info, "PROV_LOG_DEBUG- Infoblox response: [#{response}]") if @debug
   rescue => e
  raise "Error registering/querying dns name in infoblox:#{e.class}:[#{e}]"
   end

   ## Parse the xml response
   output = {}
   xmldoc = REXML::Document.new(response)
   xmldoc.elements.each("Network/IPAddress"){ |element| output['ipaddress'] = element.text }
   xmldoc.elements.each("Network/DefaultGateway"){ |element| output['gateway'] = element.text }
   xmldoc.elements.each("Network/CIDR"){ |element| output['subnet'] = element.text }

  return output, response 
  end

########################################################################################
#### METHOD MAIN #######################################################################
########################################################################################

##Set vars required for infoblox from the class
blox_hostname = $evm.object['blox_hostname']
blox_username = $evm.object['blox_username']
blox_password = $evm.object.decrypt('blox_password')

## Determine datacenter
datacenter = prov.options[:data_center]
dc = datacenter.slice(0, 2)
env = prov.options[:environment]

#user details
userid =$evm.root['user'].userid.split("@").first
username =$evm.root['user'].name
user = "#{userid}(#{username})"

#determine if ips already provisioned
ips_registered = prov.options[:ips_registered_in_infoblox] || 'f'

$evm.log(:info, "PROV_LOG_DEBUG- [ips_registered]:#{ips_registered}]" ) if @debug

#determine blox script
if ips_registered != 'f'
  blox_script = 'UB-Query-Host-Information.pl'
else
  blox_script = 'UB-Allocate-Host.pl'
end

## Set defaults for infoblox params
params = {
  'platform'  => 'RHEV',
  'username' => "#{blox_username}",
  'password' => "#{blox_password}",
  'user'     => "#{user}",
  'tagname'  => 'datacenter,rvm_env,rvm_vlanname'
}

## Add Networks
## Localalize object vars
network_info = prov.options[:network_info]
$evm.log(:info, "PROV_LOG_DEBUG- [network_info]:#{network_info.inspect}]" ) if @debug

## Set defaults
vm = prov.destination
nic_array = []
infoblox_response = [] 
#nic_array = vm.hardware.nics if vm
#read nic_array from rhev which is set in rest api call
nic_array = prov.options[:nic_array]

## Debug statements
$evm.log(:info, "PROV_LOG_DEBUG- provisionIPs:[vm]:#{vm.inspect}]" ) if @debug  
$evm.log(:info, "PROV_LOG_DEBUG- provisionIPs:[nic_array]:#{nic_array.inspect}]" ) if @debug
raise "nic_array is empty but shouldn't be. Erroring out..." if nic_array.empty?
  
## Set the network adapters based on the networks set earlier
$evm.log(:info, "PROV_LOG_DEBUG- Looping through network_info array" ) if @debug
  network_info.each do |network|
    ##Localize vars
    fqdn = network[:fqdn]
    adapter = network[:adapter_name]
    vlan = network[:network_name]
    
    ## reset vars for each loop
    ip_info = {}
    ip_hash = {}
    mac = nil
    
    ##Set additional params for infoblox
    params['fqdn'] = "#{fqdn}"
    params['tagvalue'] = "#{dc},#{env},#{vlan}"
      
    ## Obtain information from infoblox
    ip_info,ip_error = infoblox_host_request(blox_hostname, blox_script, params)
    
    ## Error checking to ensure infoblox returned info
    if ip_info.empty?
      error = ip_error.gsub("'","").strip
      raise "#{error} : Vlan: #{vlan} : Adapter:#{adapter}"
    end
      
    ## Set local vars from infoblox response
    ip = ip_info['ipaddress']
    subnet = ip_info['subnet']
    gateway = ip_info['gateway']
    
    ## Debug statements
    $evm.log(:info, "PROV_LOG_DEBUG- Working on fqdn:[#{fqdn}], adapter:[#{adapter}], ip:[#{ip}], subnet:[#{subnet}], gateway:[#{gateway}]" ) if @debug      
    
    ## Get the mac address - Loops through the VM's nics
    ## Finds the one that has the same end number as adapter
    $evm.log(:info, "PROV_LOG_DEBUG- Looping through nic_array to determine mac_address" ) if @debug
    nic_array.each do |nic|
      nic_dev = nic[:nic_name]
      nic_number = nic_dev.split(//).last
      adapter_number = "#{adapter.split(//).last.to_i + 1}"
      
      $evm.log(:info, " PROV_LOG_DEBUG- nic = #{nic_dev}" ) if @debug
      $evm.log(:info, " PROV_LOG_DEBUG- nic_number = #{nic_number}" ) if @debug
      $evm.log(:info, " PROV_LOG_DEBUG- adapter_number = #{adapter_number}" ) if @debug
      
      ## This will grab the last character in each string and
      ## compare them to determine if they're equal
      if nic_number.eql?(adapter_number) 
        mac = nic[:nic_mac]
        $evm.log(:info, " PROV_LOG_DEBUG- mac_address = #{mac}" ) if @debug        
      end     
    end
  
    raise "mac_address for #{fqdn} is null" if mac.nil? 
    
    ## Obtain the netmask
    case subnet
    when /\/21/
      netmask = "255.255.248.0"      
    when /\/22/
      netmask = "255.255.252.0"  
    when /\/23/
      netmask = "255.255.254.0"  
    when /\/24/
      netmask = "255.255.255.0"
    when /\/25/
      netmask = "255.255.255.128"
    else
      raise "Failed to find proper netmask for network: #{fqdn}"
    end
  
   ## Add the network info to another array
    ip_hash = {:fqdn => fqdn, :ip => ip, :netmask => netmask, :gateway => gateway, :adapter => adapter, :mac => mac }
   $evm.log(:info, "Adding ip_hash into infoblox_response:[#{ip_hash.inspect}]" ) if @debug
   infoblox_response << ip_hash
  end
  
  ## Set the provision option for infoblox_responses
  prov.set_option(:infoblox_response, infoblox_response)
  $evm.log(:info, "PROV_LOG- Array from infoblox_response:[#{infoblox_response.inspect}]" ) 

  exit MIQ_OK
  
rescue => err
  $evm.root['ae_result'] = 'error'
$evm.root['ae_reason'] = "Caught exception in infoblox provision_ips: #{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
end 
