#
# Description: this method will set network_connection information, and infoblox info
#
begin
  
  ## Set the serivce_template_provision_task
  stp_task = $evm.root['service_template_provision_task']
  raise "Failed to set stp_task" if stp_task.nil?  
  
  @debug=stp_task.options[:debug]

  ## Set static vars
  domain = ".unionbank.com"
  nfs_suffix = "-nfs"
  network_info = []
  
  ## Obtain vars from the provision task
  rhevh_name = stp_task.options[:rhevh_name]
  primary_network_name = stp_task.options[:primary_network]
  nfs_network_name = stp_task.options[:nfs_network]
  os_version = stp_task.options[:os_version]
  
  ## Pass domain to root to be used by another method
  stp_task.set_option(:domain, domain)  
  
  ## Debug statements
  $evm.log(:info, "PROV_LOG_DEBUG- [domain] = #{domain}") if @debug
  $evm.log(:info, "PROV_LOG_DEBUG- [nfs_suffix] = #{nfs_suffix}") if @debug 
  $evm.log(:info, "PROV_LOG_DEBUG- [primary_network_name] = #{primary_network_name}") if @debug
  $evm.log(:info, "PROV_LOG_DEBUG- [nfs_network_name] = #{nfs_network_name}") if @debug
  $evm.log(:info, "PROV_LOG_DEBUG- [os_version] = #{os_version}") if @debug
  
  ## Set IP hash, used by infoblox, cobbler, and addNics
  #adapter name is different for rhev6 and rhev7
  if os_version =~ /^rhevh6/
    primary_adapter_name = "eth0"
    sec_adapter_name = "eth3"
  else
    primary_adapter_name = "enp6s0"
    sec_adapter_name = "enp13s0"
  end
  ## Add the primary network
  network_info <<  { :type => 'primary', :fqdn => "#{rhevh_name}#{domain}", :network_name => "#{primary_network_name}", :adapter_name => "#{primary_adapter_name}" }
    
  ## Add the secondary networks
  network_info << { :type => 'nfs', :fqdn => "#{rhevh_name}#{nfs_suffix}#{domain}", :network_name => "#{nfs_network_name}", :adapter_name => "#{sec_adapter_name}" }
  
  ## Pass the hash to root
  $evm.log(:info, "PROV_LOG_DEBUG- network_info hash = #{network_info.inspect}") if @debug
  stp_task.set_option(:network_info, network_info)

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Caught exception in set_hypervisor_network_info:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
end 

