#
# Description: This method sends an e-mail when the following event is raised:
# Events: vm_provisioned
#
# Model Notes:
# 1. to_email_address - used to specify an email address in the case where the
#    vm's owner does not have an  email address. To specify more than one email
#    address separate email address with commas. (I.e. admin@example.com,user@example.com)
# 2. from_email_address - used to specify an email address in the event the
#    requester replies to the email
# 3. signature - used to stamp the email with a custom signature
#

# Get vm from miq_provision object
prov = $evm.root['miq_provision']
vm = prov.vm
raise "VM not found" if vm.nil?

@debug = prov.options[:debug]

# Override the default appliance IP Address below
appliance ||= $evm.root['miq_server'].ipaddress

# Get VM Owner Name and Email
evm_owner_id = vm.attributes['evm_owner_id']
owner = nil
owner = $evm.vmdb('user', evm_owner_id) unless evm_owner_id.nil?

to = nil
to = owner.email unless owner.nil?
to ||= $evm.object['to_email_address']
if to.nil?
  $evm.log("info", "PROV_LOG- Email not sent because no recipient specified.")
  exit MIQ_OK
end

# Assign original to_email_Address to orig_to for later use
orig_to = to

# Get from_email_address from model unless specified below
from = nil
from ||= $evm.object['from_email_address']

# Get signature from model unless specified below
signature = 'ESS-Enterprise Server Engineering(ESE) Team'
signature ||= $evm.object['signature']

#Vm Configuration details
has_tsm = prov.options[:has_tsm] || "--"
has_nfs = prov.options[:has_nfs] || "--"
app_disk = prov.options[:app_disk_size] || "--"
app_vol = prov.options[:app_disk_vol] 
app_disk_vgname = prov.options[:app_disk_vgname] 
memory_size = prov.options[:vm_memory]
vm_memory = memory_size.to_i / 1024

provider_id = prov.options[:src_ems_id]
provider = $evm.vmdb(:ext_management_system).find_by_id(provider_id).name
cluster_id = prov.options[:placement_cluster_name]
cluster = $evm.vmdb('ems_cluster').find_by_id(cluster_id).name
host_id = prov.options[:placement_host_name]
host = $evm.vmdb('host').find_by_id(host_id).name
storage_id = prov.options[:placement_ds_name]
storage = $evm.vmdb('storage').find_by_id(storage_id).name
if !app_vol.nil? && !app_vol.blank?
	app_vol_name = $evm.vmdb('storage').find_by_id(app_vol).name  
else
  app_vol_name = "--"
end 

ip ="No"
if prov.options[:ips_registered_in_infoblox] == 'f' 
  ip = "No"
else
  ip ="Yes"
end

has_autosys ="No"
if prov.options[:has_autosys] == 'f' 
  has_autosys = "No"
else
  has_autosys ="Yes"
end

table = <<-eos 
<br><br><table border=1 cellpadding=0 cellspacing=0>
<tr><td colspan=2><b>Environment Selection</b></td></tr> 
<tr><td>IP already registered<br>in infoblox:</td><td> #{ip}</td></tr>  
<tr><td>RHEV Manager:</td><td> #{provider}</td></tr>  
<tr><td>Environment:</td><td> #{prov.options[:environment]}</td></tr> 
<tr><td>Network Location:</td><td> #{prov.options[:network_location]}</td></tr> 
<tr><td>RHEV Cluster:</td><td> #{cluster}</td></tr>  
<tr><td>RHEV Host <br>(Automated selection):</td><td> #{host}</td></tr>  
<tr><td>RHEV Storage <br>(Automated selection):</td><td> #{storage}</td></tr>  

<tr><td colspan=2><b>VM Settings</b></td></tr>
<tr><td>VM Application ID:</td><td> #{prov.options[:app_id]}</td></tr>  
<tr><td>VM Name:</td><td> #{prov.options[:vm_name]}</td></tr>  
<tr><td>Puppet Profile:</td><td> #{prov.options[:puppet_profile]}</td></tr>  
<tr><td>OS Version:</td><td> #{prov.options[:os_version]}</td></tr>  
<tr><td>OS Updates:</td><td> #{prov.options[:os_updates]}</td></tr>  

<tr><td colspan=2><b>Hardware Settings</b></td></tr>
<tr><td>Number Of Sockets:</td><td> #{prov.options[:number_of_sockets]}</td></tr>  
<tr><td>Cores Per Socket:</td><td> #{prov.options[:cores_per_socket]}</td></tr>  
<tr><td>VM Memory(GB):</td><td> #{vm_memory}</td></tr>  

<tr><td colspan=2><b>Network Settings</b></td></tr>
<tr><td>Primary Network:</td><td> #{prov.options[:vlan]}</td></tr>  
<tr><td>TSM Network:</td><td> #{has_tsm}</td></tr>  
<tr><td>NFS Network:</td><td> #{has_nfs}</td></tr>

<tr><td colspan=2><b>Optional Disk Settings</b></td></tr>
<tr><td>Secondary Disk size(GB):</td><td> #{app_disk}</td></tr>  
<tr><td>Secondary Disk Volume:</td><td> #{app_vol_name}</td></tr>  
<tr><td>App Disk Volume Group Name:</td><td> #{app_disk_vgname}</td></tr>  

<tr><td colspan=2><b>Additional Settings</b></td></tr>
<tr><td>Install Autosys Agent:</td><td> #{has_autosys}</td></tr>  

</table>
eos


## VM Provisioned Email Body
body = "Greetings, "
body += "<br><br>A new request to provision a virtual machine:#{vm['name']} through Cloudforms was approved and completed on #{Time.now.strftime('%A, %B %d, %Y at %I:%M%p')}. "

if has_tsm != "--"
  tsm_body = body
  tsm_body += "<br><br>Please define OS backups for server #{vm['name']}."
  tsm_body += "<br>VM provisioner can be contacted at:#{orig_to}."
  tsm_body += "<br><br> Thank you,"
  tsm_body += "<br> #{signature}"
end

body += "#{table}"
body += "<br>VM access is available via putty/ssh, etc."
body += "<br><br>This VM will automatically be retired on #{vm['retires_on'].strftime('%A, %B %d, %Y')}, unless you request an extension. " if vm['retires_on'].respond_to?('strftime')
body += " You will receive a warning #{vm['reserved'][:retirement][:warn]} days before #{vm['name']} set retirement date." if vm['reserved'] && vm['reserved'][:retirement] && vm['reserved'][:retirement][:warn]
#body += " As the designated owner you will receive expiration warnings at this email address: #{orig_to}"
body += "<br><br> Thank you,"
body += "<br> #{signature}"

## Send email to the user
$evm.log("info", "PROV_LOG- Sending Successful email to <#{to}> from <#{from}>")
subject = "Your virtual machine request has Completed - VM: #{vm['name']}"
completed_to = "#{to}"
if (!@debug)
  completed_to += ',haarika.bathineni@unionbank.com'
end
$evm.execute('send_email', completed_to, from, subject, body)

## Send emails if debug is false
if (!@debug)
  ## Send email to security team if debug is false
  from = "#{to}"
  security_to = "Mohammad.Rahman@unionbank.com,Timothy.Shambrey@unionbank.com,#{to}" 
  subject = "A new virtual machine request has Completed - VM: #{vm['name']}"
  $evm.log("info", "PROV_LOG- Sending email to security team <#{security_to}>")
  $evm.execute('send_email', security_to, from, subject, body)

  ## Send email to storage team if tsm is selected
  if has_tsm != "--"
      from = "#{to}"
      storage_to = "stm-bkp@otrs.uboc.com, itg-to-ess-esm@unionbank.com,#{to}"
      subject = "Requesting base OS TSM backups for new VM:#{vm['name']}"    
      $evm.log("info", "PROV_LOG- Sending email to storage team <#{storage_to}>")
      $evm.execute('send_email', storage_to, from, subject, tsm_body)
  end
end 
