#
# Description: This method checks the ostype and modifies according to cobbler profile.
#

require 'restclient'
require 'nokogiri'

prov = $evm.root['miq_provision']
@debug = prov.options[:debug]
@debug = 1
begin

def call_rhev(servername, username, password, action, ref=nil, body_type=:xml, body=nil)
	#
	# If ref is a url then use that one instead
	#
	unless ref.nil?
		url = ref if ref.include?('http')
	end
	
	url ||= "https://#{servername}#{ref}"
	rest = RestClient::Request.new(
          :method => action,
          :url => url,
          :user => username,
          :password => password,
          :headers => { :content_type=> :xml, :accept=>:xml },
    	  :verify_ssl => false,
          :payload => body)      
  
  	response_str = rest.execute
	response_str.gsub! '\"', '"'
  	response_str.gsub! '\n', ''
	response = Nokogiri::XML(response_str)
  
	return response
rescue RestClient::Exception => err
	$evm.log(:info, "The REST request failed with code: #{err.response.code}") unless err.response.nil?
	$evm.log(:info, "The response body was:\n#{err.response.body.inspect}") unless err.response.nil?
  	$evm.root['ae_result'] = 'error'
  	$evm.root['ae_reason'] = "Caught exception in add_disk:#{err.class}:#{err}"
  	$evm.log('error', "#{$evm.root['ae_reason']}")
rescue => err
	$evm.root['ae_result'] = 'error'
  	$evm.root['ae_reason'] = "Caught exception in add_disk-call_rhev:#{err.class}:#{err}"
  	$evm.log('error', "#{$evm.root['ae_reason']}")
end

vm = prov.destination
ems = vm.ext_management_system

servername = ems.hostname
username = ems.authentication_userid
password = ems.authentication_password

dialog_os_type = prov.options[:os_version]
if dialog_os_type =~ /rhel6u6_64_RHEV_CF/
	os_type = "rhel_6x64"
else
	os_type = "rhel_5x64"
end

###check if the vm has this os type

vm.operating_system.attributes.sort.each { |k, v| 
  $evm.log("info","VM:<#{vm.name}> Operating System - #{k}: #{v.inspect}")
}
  
b_os_type = vm.operating_system.product_name  
if  b_os_type == os_type
	$evm.root['ae_result'] = 'ok'
	$evm.log(:info, "No Need to change the OS Type")
	exit MIQ_OK
end
  
$evm.log(:info, "dialog os type: #{dialog_os_type}")  
  $evm.log(:info, "before os type: #{b_os_type}")  

  $evm.log(:info, "inspect vm: #{vm.inspect}") 
#
# build xml body for the RHEV REST API call
#
body = "<vm>"
body += "<os type='#{os_type}'>"
body += "<boot dev='hd'/>"
body += "</os>"
body += "</vm>"

ref = vm.ems_ref

$evm.log(:info, "servername: #{servername}")
$evm.log(:info, "username: #{username}")
$evm.log(:info, "password: #{password}")
$evm.log(:info, "body: #{body}")
$evm.log(:info, "ref: #{ref}")

doc = call_rhev(servername, username, password, :put, "#{ref}", :xml, body)
  
after_os_type = vm.operating_system.product_name
  $evm.log(:info, "after os type: #{after_os_type}")    
if after_os_type == os_type
	$evm.root['ae_result'] = 'ok'
	exit MIQ_OK
else
	raise  "Failed to set the VM OS Type" 
end

rescue => err
	$evm.root['ae_result'] = 'error'
  	$evm.root['ae_reason'] = "Caught exception in Set_OS_TYPE:#{err.class}:#{err}"
  	$evm.log('error', "#{$evm.root['ae_reason']}")
  	#exit MIQ_ABORT
end
