#
# Description: <Method description here>
#
begin

  ## Set the provision and vm objects
  prov = $evm.root['miq_provision']
  @debug = prov.options[:debug]
  
  ## Testing vars when using simulation
  #vm_name        = 'chesesbx299'
  #data_center    = 'chdc'
  #environment    = 'SBX'
  #puppet_profile = 'baseos'
  
  ## Pull variables from provision object
  vm_name        = prov.options[:vm_name] if prov
  data_center    = prov.options[:data_center] if prov
  environment    = prov.options[:environment] if prov
  puppet_profile = prov.options[:puppet_profile] if prov
  patchdate      = prov.options[:os_updates] if prov
  app_stg_id     = prov.options[:app_disk_vol] if prov
  app_stg_vg     = prov.options[:app_disk_vgname] if prov
  has_tsm        = prov.options[:has_tsm] || ''
  has_autosys    = prov.options[:has_autosys] || 'f'
  
  missing_fields = ['vm_name', 'data_center', 'environment', 'puppet_profile', 'patchdate'].collect do | key |
    key unless eval(key)
  end.compact
  unless missing_fields.empty?
    $evm.log('error', "Missing required variables: [#{missing_fields}]")
    exit MIQ_ABORT
  end

  ## Set up the classes_array and add additional classes based on options
  classes_array = [ puppet_profile ]
  classes_array << 'tsm_client::v6_4_3' if !has_tsm.blank?
  classes_array << 'autosys' if has_autosys != 'f'
  
  ## Standard hiera entries
  hiera_actions = {
    "#{data_center}/#{environment.upcase()}/#{vm_name}.yaml"=>{
      'classes'=>{
        :action=>:assign,
        :value=>classes_array
      }
    },
    "#{data_center}/#{environment.upcase()}/#{vm_name}.yumconfig.yaml"=>{
      'patchdate'=> {
        :action=>:assign,
        :value=> patchdate
      }
    }  
  }

  ## Add additional hiera entries for app_storage if selected
  if app_stg_id && app_stg_vg
   hiera_actions.merge!(
     "#{data_center}/#{environment.upcase()}/#{vm_name}.lvm.yaml"=>{
       'volume_groups'=>{
         :action=>:assign,
         :value=>{
           "#{app_stg_vg}"=>{
             'physical_volumes'=>["/dev/vdb"]
           }
         }
       }
     }
   )
  end  

  $evm.log("info", "PROV_LOG- Assigning Puppet system roles: [#{hiera_actions}]")
  $evm.object['hiera_actions'] = hiera_actions
  path = `echo $PATH`
  $evm.log("info","PROV_LOG- PATH = #{path}")
  exit MIQ_OK

rescue => err
  $evm.root['ae_result'] = 'error'
$evm.root['ae_reason'] = "Caught exception in Puppet/stashRepos/hiera_prepare_registration:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
end
