#
# Description: <Method description here>
#
begin
  require 'fileutils'
  require 'git'
  require 'timeout'

  DEFAULT_TIMEOUT = 120

  class GitLogger
    def method_missing(m, *args, &block)
      $evm.log('info', "GIT: #{args}") if @debug
    end
  end
  
  def update_local_git_repo(git_repo_remote, git_repo_local)
    begin
      $evm.log('info', 'Attempting to open modules git repo.') if @debug
      git = Git.open(git_repo_local, :log=>GitLogger.new)
    rescue ArgumentError
      $evm.log('warn', 'Unable to open modules repo.  Cloning from source.') if @debug
      FileUtils.rm_rf(git_repo_local)
      git = Git.clone(git_repo_remote, git_repo_local)
      git.config('user.name', 'CloudForms')
      git.config('user.email', 'cloudforms@unionbank.com')
      git = Git.open(git_repo_local, :log=>GitLogger.new)
    end

    git.reset_hard('origin/HEAD')
    git.checkout('master')
    git.pull()
  end

  def get_profiles(git_repo_local, local_folder)
    Dir.chdir("#{git_repo_local}/#{local_folder}")
    profiles = Dir.glob('*').select {|f| File.directory? f }
    return profiles
  end 

##############################################################################################
## MAIN ######################################################################################
##############################################################################################
  ## Set the provision and vm objects
  @debug = $evm.object['debug']
 
  ## Local variables
  puppet_profiles = []
  git_repo_hostname = $evm.object['git_repo_hostname']
  git_repo_path     = $evm.object['git_repo_path']
  git_repo_username = $evm.object['git_repo_username']
  git_repo_password = $evm.object.decrypt('git_repo_password')
  git_repo_remote = File.join("http://#{git_repo_username}:#{git_repo_password}@#{git_repo_hostname}", git_repo_path)
  git_repo_local = "/root/union_bank/git/modules"  

  missing_fields = ['git_repo_hostname', 
                    'git_repo_path', 
                    'git_repo_username', 
                    'git_repo_password'].collect do | key |
    key unless eval(key)
  end.compact
  unless missing_fields.empty?
    raise("Missing required variables:[#{missing_fields}]")
  end

  begin
    Timeout.timeout(DEFAULT_TIMEOUT) do
      ## Update the local repo
      update_local_git_repo(git_repo_remote, git_repo_local)

      ## Load the profiles
      puppet_profiles = get_profiles(git_repo_local, 'profiles')
      $evm.log('info', "Puppet profiles Array: #{puppet_profiles.inspect}")
      
      ## Set an object to be used by another method
      $evm.root['puppet_profiles_array'] = puppet_profiles
    end
  rescue Timeout::Error => e
    raise("Timed out waiting for stash modules repo:[#{e}]")
  rescue => e
    raise("Error occurred accessing stash modules repo:[#{e}]")
  end  
  exit MIQ_OK

rescue => err
  $evm.log('error', "Caught exception in Puppet/stashRepos/modules_get_profiles:#{err.class}:#{err}, returning empty puppet_profiles")  
  $evm.root['puppet_profiles_array'] = []
end
