begin
  require 'restclient'
  require 'nokogiri'

#------------------------------------------------------------------------------
  def call_rhev(servername, username, password, action, ref=nil, body_type=:xml, body=nil, counter=0, task=nil)
  #
  # If ref is a url then use that one instead
  #
  unless ref.nil?
	url = ref if ref.include?('http')
  end
	
  url ||= "https://#{servername}#{ref}"
	
  $evm.log(:info, "PROV_LOG- Calling RHEVM at: #{url}")
  $evm.log(:info, "PROV_LOG- Action: #{action}")
  
	
  rest = RestClient::Request.new(
        :method => action,
        :url => url,
        :user => username,
        :password => password,
        :headers => { :content_type=> :xml, :accept=>:xml },
        :verify_ssl => false,
        :payload => body,
        :timeout => 300 )      
  
  response_str = rest.execute
  response_str.gsub! '\"', '"'
  response_str.gsub! '\n', ''

  $evm.log(:info, "PROV_LOG_DEBUG- xml - #{response_str}") if @debug   
  response = Nokogiri::XML(response_str)
  
  return response

rescue RestClient::RequestTimeout
  $evm.log(:info, "PROV_LOG- The REST request Timed out for input_action #{task} but continuing.")
  exit MIQ_OK  
 
rescue RestClient::Exception => err
    if err.response.nil?
      $evm.log(:info, "PROV_LOG- The REST request failed but did not return a return code")
      exit MIQ_OK
    else
      $evm.log(:info, "PROV_LOG- The REST request failed with code: #{err.response.code}")
      $evm.log(:info, "PROV_LOG- The response body was:\n#{err.response.body.inspect}")
    end
  
    ## Only raise the error if the counter has reached 0
    #if counter == 0
    #  raise "rest call to rhevm failed:#{err.class}:#{err}"
    #else
    #  return 'retry'
    #end    
rescue => err
    raise "call_rhev method failed:#{err.class}:#{err}"
end
#------------------------------------------------------------------------------
#------------------------------------------------------------------------------
# Start of main code
#------------------------------------------------------------------------------  
  ## Set the serivce_template_provision_task
  stp_task = $evm.root['service_template_provision_task']
  raise "Failed to set stp_task" if stp_task.nil?  
  
  @debug=stp_task.options[:debug]
  
  ## Localize inputs
  input_action = $evm.inputs['action']

  ## Localize vars pulled from root
  rhevh_name     = stp_task.options[:rhevh_name]
  redhat_cluster = stp_task.options[:redhat_cluster]
  cluster_name   = redhat_cluster.name
  rhevm_name     = stp_task.options[:rhevm_name]  
  rhevm_userid   = stp_task.options[:rhevm_userid]
  rhevm_password = stp_task.options[:rhevm_password]
  hypervisor_data = stp_task.options[:hypervisor_data]
  hv_href        = "#{hypervisor_data[:hv_href]}"

  missing_fields = ['rhevh_name', 'redhat_cluster', 'rhevm_name', 'rhevm_userid', 'rhevm_password','hypervisor_data', 'hv_href'].collect do | key |
    key unless eval(key)
  end.compact
  unless missing_fields.blank?
    raise "Missing required variables: [#{missing_fields}]" 
  end  
  
  ## set defaults
  action_type = :post
  counter = 5
  
  ## Determine body based on action
  case input_action
  when 'approve'
    body    = "<action><cluster><name>#{cluster_name}</name></cluster></action>"
    hv_href = "#{hv_href}/#{input_action}"    
  when 'deactivate', 'activate', 'commitnetconfig'
    body    = "<action></action>"
    hv_href = "#{hv_href}/#{input_action}"
  when 'power_management'
    ucs_mgr  = stp_task.options[:ucs_manager]
    ucs_user = stp_task.options[:ucs_user]
    ucs_pw   = stp_task.options[:ucs_pw]
    domain   = stp_task.options[:domain]
    action_type = :put
    body =  "<host><power_management type=\"cisco_ucs\"><enabled>true</enabled><address>#{ucs_mgr}#{domain}</address><username>#{ucs_user}</username><password>#{ucs_pw}</password>"
    body += "<options><option name=\"suborg\" value=\"org-Linux\"/><option name=\"secure\" value=\"true\"/><option name=\"ssl_insecure\" value=\"1\"/><option name=\"slot\" value=\"SP_#{rhevh_name}\"/></options>"
    body += "<pm_proxies/><agents><agent type=\"cisco_ucs\"><address>#{ucs_mgr}</address><username>#{ucs_user}</username><password>#{ucs_pw}</password>"
    body += "<options><option name=\"suborg\" value=\"org-Linux\"/><option name=\"ssl_insecure\" value=\"1\"/><option name=\"secure\" value=\"true\"/><option name=\"slot\" value=\"SP_#{rhevh_name}\"/></options>"
    body += "<order>1</order></agent></agents><automatic_pm_enabled>true</automatic_pm_enabled><kdump_detection>true</kdump_detection></power_management>"
    body += "<protocol>stomp</protocol></host>"
  end
    
  ## Call rhev
  $evm.log(:info, "PROV_LOG- Rhev #{input_action} hypervisor: #{rhevh_name}")  
  $evm.log(:info, "PROV_LOG- Hypervisor #{input_action} Request: #{hv_href}")
  
  doc = call_rhev(rhevm_name, rhevm_userid, rhevm_password, action_type, hv_href, :xml, body, counter, input_action)
  
 # while counter >= 0
 #   doc = call_rhev(rhevm_name, rhevm_userid, rhevm_password, action_type, hv_href, :xml, body, counter, input_action) 
 #   if doc.eql?('retry')
 #     counter -= 1
 #     sleep 120
 #   else
 #     break
 #   end
 # end

  exit MIQ_OK

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Caught exception in change_hypervisor_state:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
end
