
require 'restclient'
require 'nokogiri'

begin


def call_rhev(servername, username, password, action, ref=nil, body_type=:xml, body=nil, task=nil)
	#
	# If ref is a url then use that one instead
	#
	unless ref.nil?
		url = ref if ref.include?('http')
	end
	
	url ||= "https://#{servername}#{ref}"
	rest = RestClient::Request.new(
          :method => action,
          :url => url,
          :user => username,
          :password => password,
          :headers => { :content_type=> :xml, :accept=>:xml },
    	  :verify_ssl => false,
          :payload => body,
      	  :timeout => 300)      
  
  	response_str = rest.execute
  
  	response_str.gsub! '\"', '"'
  	response_str.gsub! '\n', ''

    response = Nokogiri::XML(response_str)
  	
	return response
rescue RestClient::RequestTimeout
  $evm.log(:info, "PROV_LOG- The REST request Timed out for task #{task} but continuing.")
  exit MIQ_OK  
rescue RestClient::Exception => err
	$evm.log(:info, "PROV_LOG- The REST request failed with code: #{err.response.code}") unless err.response.nil?
	$evm.log(:info, "PROV_LOG- The response body was:\n#{err.response.body.inspect}") unless err.response.nil?
    raise "rest call to rhevm failed:#{err.class}:#{err}"
rescue => err
	raise "call_rhev method failed:#{err.class}:#{err}"
end

##main code
task = $evm.inputs['task']

prov = $evm.root['miq_provision']
vm = prov.destination
vmname = vm.name
ems = vm.ext_management_system
servername = ems.hostname
username = ems.authentication_userid
password = ems.authentication_password
body = nil
ref = vm.ems_ref


if task == 'poweron'
  body = "<action/>"

  doc = call_rhev(servername, username, password, :post, "#{ref}/start", :xml, body, task)
  creation_status = doc.xpath("action/status/state").text	
  $evm.log(:info, "PROV_LOG- VM #{vmname}: Started Status is #{creation_status}.")
  
elsif task == 'configureNetworkBoot'
  body = "<vm><os><boot dev=\"hd\" /><boot dev=\"network\" /></os></vm>"
  doc = call_rhev(servername, username, password, :put, "#{ref}", :xml, body, task)
  $evm.log(:info, "PROV_LOG- VM #{vmname}:#{task} task completed.")
  
else
  #validate till the power status is up/down
  doc = call_rhev(servername, username, password, :get, "#{ref}", :xml, body, task)
  power_status = doc.xpath("vm/status/state").text  
  counter = 40
  	while power_status != "#{task}"
      counter -= 1
      if counter == 0
        raise "VM #{vmname}: Timed out waiting for power #{task}. Current Status:#{power_status}"
      else
        sleep 60
        doc1 = call_rhev(servername, username, password, :get, "#{ref}", :xml, body, task)
 		power_status = doc1.xpath("vm/status/state").text 
        $evm.log(:info, "PROV_LOG- VM #{vmname}: Status should be #{task}. Current status is #{power_status} - retry:#{counter}.")
      end
    end
end
      
exit MIQ_OK 

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Caught exception in change_vm_state:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
end
