begin
  require 'restclient'
  require 'nokogiri'

#------------------------------------------------------------------------------
  def call_rhev(servername, username, password, action, ref=nil, body_type=:xml, body=nil, return_resp=false )
  #
  # If ref is a url then use that one instead
  #
  unless ref.nil?
	url = ref if ref.include?('http')
  end
	
  url ||= "https://#{servername}#{ref}"
	
  if @debug
	$evm.log(:info, "PROV_LOG_DEBUG- Calling RHEVM at: #{url}")
	$evm.log(:info, "PROV_LOG_DEBUG- Action: #{action}")
    $evm.log(:info, "PROV_LOG_DEBUG- Body: #{body}")    
  end
	
  rest = RestClient::Request.new(
        :method => action,
        :url => url,
        :user => username,
        :password => password,
        :headers => { :content_type=> :xml, :accept=>:xml },
        :verify_ssl => false,
        :payload => body,
        :timeout => 300 )      
  
  response_str = rest.execute
  response_str.gsub! '\"', '"'
  response_str.gsub! '\n', ''

  $evm.log(:info, "xml - #{response_str}") if @debug
  response = Nokogiri::XML(response_str)     

  return response if return_resp

rescue RestClient::Exception => err
  $evm.log(:info, "The REST request failed with code: #{err.response.code}") unless err.response.nil?
  $evm.log(:info, "The response body was:\n#{err.response.body.inspect}") unless err.response.nil?
  raise "rest call to rhevm failed:#{err.class}:#{err}"
rescue => err
    raise "call_rhev method failed:#{err.class}:#{err}"
end
#------------------------------------------------------------------------------
#------------------------------------------------------------------------------
# Start of main code
#------------------------------------------------------------------------------  
  ## Set the serivce_template_provision_task
  stp_task = $evm.root['service_template_provision_task']
  raise "Failed to set stp_task" if stp_task.nil?  
  
  @debug=stp_task.options[:debug]
  
  ## Localize vars pulled from root
  rhevh_name     = stp_task.options[:rhevh_name]    
  rhevm_name     = stp_task.options[:rhevm_name]
  rhevm_userid   = stp_task.options[:rhevm_userid]
  rhevm_password = stp_task.options[:rhevm_password]
  hypervisor_data = stp_task.options[:hypervisor_data]
  hv_href        = "#{hypervisor_data[:hv_href]}" unless hypervisor_data.blank? 
  nfs_network_info = stp_task.options[:nfs_network_info]
  nfs_ip = nfs_network_info[:ip]  unless nfs_network_info.nil?
  nfs_netmask = nfs_network_info[:netmask] unless nfs_network_info.blank?
  nfs_adapter = nfs_network_info[:adapter] unless nfs_network_info.blank?

  missing_fields = ['rhevm_name', 'rhevm_userid', 'rhevm_password','hypervisor_data',
    'hv_href', 'nfs_network_info', 'nfs_ip', 'nfs_netmask', 'nfs_adapter' ].collect do | key |
    key unless eval(key)
  end.compact
  unless missing_fields.blank?
    raise "Missing required variables: [#{missing_fields}]" 
  end    
  
  ## Obtain the nics list from the hypervisor
  hv_href = "#{hv_href}/nics"
    doc = call_rhev(rhevm_name, rhevm_userid, rhevm_password, :get, hv_href, :xml, nil, true)
 
  ## Set the doc root
  doc_root = doc.root
  
  #get all the nic names to find nfs
  arr =[]
  doc_root.xpath("host_nic").select{|nic|
  	nic_name=nic.at_xpath("name").text
  	arr << nic_name
  }
 
  arr.sort_by! { |n| n.scan(/[0-9.]/).join.to_f }
    
  nfs_adapter_name = arr.last
  $evm.log("info", "PROV_LOG- Found the nfs adaptner name as #{nfs_adapter_name}")
    
  ## obtain the nics from output that have the nfs adapter in the name
  nics = doc_root.xpath("host_nic").select{|nic| nic.at_xpath("name").text =~ /#{nfs_adapter_name}/ }
  raise "Did not detect the correct number of nfs nics: Count[#{nics.count}]...Erroring out" if nics.count != 1
    
  ## Set the nfs nic
  nfs_nic = nics.first
  nfs_href = nfs_nic['href'].to_s  
          
  ## Calling RHEV to set the NFS IP
  body = "<host_nic><ip address=\"#{nfs_ip}\" netmask=\"#{nfs_netmask}\"/><boot_protocol>static</boot_protocol></host_nic>"
  $evm.log("info", "PROV_LOG- Configuring Hypervisor NFS network: IP: #{nfs_ip} Netmask:#{nfs_netmask}")
  call_rhev(rhevm_name, rhevm_userid, rhevm_password, :put, nfs_href, :xml, body)  
  sleep  60
    
  exit MIQ_OK

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Caught exception in configure_hypervisor_nfs_ip:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
end
