begin
  require 'restclient'
  require 'nokogiri'

#------------------------------------------------------------------------------
def call_rhev(servername, username, password, action, ref=nil, body_type=:xml, body=nil)
  #
  # If ref is a url then use that one instead
  #
  unless ref.nil?
	url = ref if ref.include?('http')
  end
	
  url ||= "https://#{servername}#{ref}"
	
  if @debug
	$evm.log(:info, "PROV_LOG_DEBUG- Calling RHEVM at: #{url}")
	$evm.log(:info, "PROV_LOG_DEBUG- Action: #{action}")
    $evm.log(:info, "PROV_LOG_DEBUG- Body: #{body}")    
  end
	
  rest = RestClient::Request.new(
        :method => action,
        :url => url,
        :user => username,
        :password => password,
        :headers => { :content_type=> :xml, :accept=>:xml },
        :verify_ssl => false,
        :payload => body,
        :timeout => 300 )      
  
  response_str = rest.execute
  response_str.gsub! '\"', '"'
  response_str.gsub! '\n', ''

  $evm.log(:info, "xml - #{response_str}") if @debug   
  response = Nokogiri::XML(response_str)
  
  return response

rescue RestClient::Exception => err
  $evm.log(:info, "The REST request failed with code: #{err.response.code}") unless err.response.nil?
  $evm.log(:info, "The response body was:\n#{err.response.body.inspect}") unless err.response.nil?
  raise "rest call to rhevm failed:#{err.class}:#{err}"
rescue => err
    raise "call_rhev method failed:#{err.class}:#{err}"
end
#------------------------------------------------------------------------------
#------------------------------------------------------------------------------
# Start of main code
#------------------------------------------------------------------------------  
  ## Set the serivce_template_provision_task
  stp_task = $evm.root['service_template_provision_task']
  raise "Failed to set stp_task" if stp_task.nil?  
  
  @debug=stp_task.options[:debug]

  ## Localize vars pulled from root
  rhevh_name     = stp_task.options[:rhevh_name]
  domain         = stp_task.options[:domain]
  fqdn           = "#{rhevh_name}#{domain}"  
  redhat_cluster = stp_task.options[:redhat_cluster]
  cluster_name   = redhat_cluster.name unless redhat_cluster.blank?
  rhevm_name     = stp_task.options[:rhevm_name]  
  rhevm_userid   = stp_task.options[:rhevm_userid]
  rhevm_password = stp_task.options[:rhevm_password]
  hypervisor_data = stp_task.options[:hypervisor_data]
  hv_href        = "#{hypervisor_data[:hv_href]}" unless hypervisor_data.blank? 

  missing_fields = ['rhevh_name', 'domain', 'redhat_cluster', 'rhevm_name', 'rhevm_userid', 'rhevm_password','hypervisor_data',
    'hv_href'].collect do | key |
    key unless eval(key)
  end.compact
  unless missing_fields.blank?
    raise "Missing required variables: [#{missing_fields}]" 
  end    
  
  ## Get a list of hosts in the cluster
  hosts = redhat_cluster.hosts

  ## Raise an error if the 
  if hosts.blank?
    raise "This is the first hypervisor in the Cluster. Please manually configure hypervisor networks"
  end

  ## Loop through the hosts and pull the one that was last created
  hosts.delete_if {|obj| obj.power_state != "on"}
  if hosts.empty?
    raise "No usable hypervisor found for network template. Please manually configure hypervisor networks"
  end  
  hosts.sort_by! {|a| a.created_on}
  template_host = hosts[0]
  provision_host = $evm.vmdb('host').find_by_name(fqdn)

  nics  = template_host.hardware.nics.sort_by! { |n| n.device_name.scan(/[0-9.]/).join.to_f }
  $evm.log("info", "PROV_LOG_DEBUG- template_host nics : #{nics.inspect}") if @debug
  
  #prov_nics = provision_host.hardware.nics.sort_by! { |n| n.device_name.scan(/[0-9.]/).join.to_f }
  #$evm.log("info", "PROV_LOG_DEBUG- provision_host nics : #{prov_nics.inspect}") if @debug
  
  #get the prov nics by calling rhev API
  hv_href = "#{hv_href}/nics"
  doc = call_rhev(rhevm_name, rhevm_userid, rhevm_password, :get, hv_href, :xml, nil)
  doc_root = doc.root
  nic_arr =[]
  doc_root.xpath("host_nic").select{|nic|
  	 nic_name=nic.at_xpath("name").text
     nic_uid =nic.at_xpath("actions/link[@rel='attach']/@href").text
     nic_arr << {"device_name" =>"#{nic_name}" , "uid_ems" => "#{nic_uid}"} 
  }
  nic_arr.sort_by! { |n| n['device_name'].scan(/[0-9.]/).join.to_f }
  $evm.log("info", "PROV_LOG_DEBUG- provision_host nics : #{nic_arr.inspect}") 
  
  ## Loop through the new nics and old nics and match them up amongst themselves based on the adapter count
  ## Then execute the rhev command to set the vlans on each appropriate network interface
  prov_count = 1
  template_count = 0
  
  nic_arr.each do |nic|
    $evm.log(:info, "PROV_LOG- prov_nic: #{nic['device_name']} count: #{prov_count}")
    nics.each do |template_nic|
      if /\./.match(template_nic.device_name) && prov_count == template_count
        request = "#{nic['uid_ems']}"
        body = "<action><network><name>#{template_nic.switch.name}</name></network></action>"      
        ## Call RHEV to configure the network vlans on the interface
        $evm.log("info", "PROV_LOG- Configuring vlans-Template Host: #{template_host} - Template Nic:#{template_nic.device_name}")
        call_rhev(rhevm_name, rhevm_userid, rhevm_password, :post, request, :xml, body)
      elsif /\./.match(template_nic.device_name)
        $evm.log(:info, "PROV_LOG_DEBUG- skipping: #{template_nic.device_name}, template_count:#{template_count}" )
        next
      else
        $evm.log(:info, "PROV_LOG_DEBUG- template_nic: #{template_nic.device_name} adding to count: #{template_count}")
        template_count+= 1
      end        
    end
    prov_count+= 1
    template_count = 0
  end

  exit MIQ_OK

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Caught exception in configure_hypervisor_vlans:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
end
