#
# Description: checks if host exists in vmdb and delete in RHEV if in maintenance status
#


require 'restclient'
require 'nokogiri'

begin


def call_rhev(servername, username, password, action, ref=nil, body_type=:xml, body=nil)
	#
	# If ref is a url then use that one instead
	#
	unless ref.nil?
		url = ref if ref.include?('http')
	end
	
	url ||= "https://#{servername}#{ref}"
  if @debug
    $evm.log("info", "PROV_LOG_DEBUG- Calling RHEVM at: #{url}") 
	$evm.log("info", "PROV_LOG_DEBUG- Action: #{action}")
  end
  
  header_option = { :accept=>:xml }
  if action == 'get'
      header_option = { :content_type=>:xml, :accept=>:xml }    
  end
  
  rest = RestClient::Request.new(
          :method => action,
          :url => url,
          :user => username,
          :password => password,
          :headers => header_option,
    	  :verify_ssl => false,
          :payload => body,
          :timeout => 300)      
  
  	response_str = rest.execute
  	response_str.gsub! '\"', '"'
  	response_str.gsub! '\n', ''

  	response = Nokogiri::XML(response_str)
    return response,nil,nil
  
rescue RestClient::Exception => err
  unless err.response.nil?
    $evm.log("info", "The REST request failed with code: #{err.response.code}")
	$evm.log("info", "The response body was:\n#{err.response.body.inspect}")
    unless err.response.code.nil?
      return response,err.response,err.response.code
    else
      return response,err.response,nil
    end
  else
      return response,err,nil
  end
rescue => err
  $evm.log("info", "[#{err}]\n#{err.backtrace.join("\n")}")
    return nil,err,nil
end
##########################################################################################################
#### Begin Main
##########################################################################################################

## Set the serivce_template_provision_task
stp_task = $evm.root['service_template_provision_task']
raise "Failed to set stp_task" if stp_task.nil?  
@debug=stp_task.options[:debug]

## Localize vars pulled from root
rhevh_name     = stp_task.options[:rhevh_name]
rhevm_name     = stp_task.options[:rhevm_name]  
rhevm_userid   = stp_task.options[:rhevm_userid]
rhevm_password = stp_task.options[:rhevm_password]
 
####Find host in vmdb and delete in VMDB****
domain = '.unionbank.com' 
rhevh_available = nil
fqdn = "#{rhevh_name}#{domain}"
rhevh_available = $evm.vmdb('host').find_by_name(fqdn)

if rhevh_available.nil? 
  $evm.log("info", "PROV_LOG- Host is not present in vmdb.")
  exit MIQ_OK
else
  hv_href = rhevh_available.ems_ref
  #rhevh_available.id.remove_from_vmdb
  $evm.log("info", "PROV_LOG_DEBUG- Host is present and should be removed from vmdb.") if @debug
end  

############################################


missing_fields = ['rhevh_name', 'domain', 'rhevm_name', 'rhevm_userid', 'rhevm_password',
    'hv_href'].collect do | key |
    key unless eval(key)
end.compact
unless missing_fields.blank?
    raise "Missing required variables: [#{missing_fields}]" 
end    

#rest api call to fetch host details
doc,error,error_code = call_rhev(rhevm_name, rhevm_userid, rhevm_password, :get, hv_href, :xml, nil)
if "#{error_code}" == '404'
   $evm.log("info", "PROV_LOG- No Host to delete in RHEVM")
   exit MIQ_OK
elsif error != nil
  raise "querying rhevm for hypervisor[#{fqdn}] failed with error[#{error}], error_code[#{error_code}]"
else
	status = doc.xpath("host/status/state").text
    $evm.log("info", "PROV_LOG_DEBUG- Host is present and the status is #{status}") if @debug
    #rest api call to delete if status is maintenance
    if (status == 'maintenance')
		doc = call_rhev(rhevm_name, rhevm_userid, rhevm_password, :delete, hv_href, :xml, nil)
        $evm.log("info", "PROV_LOG- Host is deleted in RHEVM")
    else
      raise "Host #{rhevh_name} exists and status is #{status}, should be maintenance" 
    end
end 

#exit MIQ_ABORT

rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Caught exception in delete_hypervisor:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
end
