#
# Description: connect to rhev through rest API to get the nic count.
#

require 'restclient'
require 'nokogiri'

begin


def call_rhev(servername, username, password, action, ref=nil, body_type=:xml, body=nil)
	#
	# If ref is a url then use that one instead
	#
	unless ref.nil?
		url = ref if ref.include?('http')
	end
	
	url ||= "https://#{servername}#{ref}"
	rest = RestClient::Request.new(
          :method => action,
          :url => url,
          :user => username,
          :password => password,
          :headers => { :content_type=> :xml, :accept=>:xml },
    	  :verify_ssl => false,
          :payload => body)      
  
  	response_str = rest.execute
  
  	response_str.gsub! '\"', '"'
  	response_str.gsub! '\n', ''

    response = Nokogiri::XML(response_str)
  
	return response
rescue RestClient::Exception => err
	$evm.log(:info, "The REST request failed with code: #{err.response.code}") unless err.response.nil?
	$evm.log(:info, "The response body was:\n#{err.response.body.inspect}") unless err.response.nil?
    raise "rest call to rhevm in wait for Mac addrress  failed:#{err.class}:#{err}"
rescue => err
      raise "call_rhev method in wait for Mac addrress failed:#{err.class}:#{err}"
end

##main code
prov = $evm.root['miq_provision']
vm = prov.destination
ems = vm.ext_management_system
servername = ems.hostname
username = ems.authentication_userid
password = ems.authentication_password
body = nil
ref = vm.ems_ref
vm_name = vm.name if vm
      
networks = prov.options[:networks]
network_count = networks.count.to_i


#validate till the nic count is same as network count
doc = call_rhev(servername, username, password, :get, "#{ref}/nics", :xml, body)
vm_nic_count = doc.xpath("nics/nic/name").count  
 
counter = 20
while network_count != vm_nic_count
	counter -= 1
    if counter == 0
      raise "Timed out Waiting for all nics to become available network_count: #{network_count} - nic_count: #{vm_nic_count}"
    else
          sleep 30
          doc = call_rhev(servername, username, password, :get, "#{ref}/nics", :xml, body)
          vm_nic_count = doc.xpath("nics/nic/name").count 
    end
end 
 	    
$evm.log('info', "PROV_LOG- All nics successfully registered for VM:[#{vm_name}]")      
      
####store the nic details in an array
nic_array =[]
  doc.xpath("nics/nic").each do |row|
  nic_name = row.xpath("./name").text
  nic_mac = row.xpath("./mac/@address").text
  nic_array << {:nic_name => nic_name, :nic_mac => nic_mac}
end
prov.set_option(:nic_array, nic_array)
  
exit MIQ_OK 

rescue => err
  $evm.root['ae_result'] = 'error'
      $evm.root['ae_reason'] = "Caught exception in Wait_for_vm_macAddress:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
end
