#
# Description: this method will obtain hostname and storage for the cluster selected. 
#
begin
  
  @debug= $evm.object['debug']
  
  ## Obtain the redhat cluster from the dialog  	
  cluster_id = $evm.object['dialog_placement_cluster_name'] || nil
  vm_memory = $evm.object['dialog_vm_memory']
  rhev_host = ""

  ## Determine if cluster_id is null and set default value if it is
  if !cluster_id.eql? nil
    $evm.log(:info, "cluster ID: #{cluster_id}") if @debug

    #get cluster object for the selected cluster
    redhat_cluster = $evm.vmdb('ems_cluster').find_by_id(cluster_id)
    
    #required memory on cluster - vm memory +256 gb.available cluster memory should be greater than this.
    req_memory = vm_memory.to_i + 256000
    cluster_mem = redhat_cluster.aggregate_memory.to_i - redhat_cluster.derived_memory_used_avg_over_time_period.to_i
    $evm.log(:info, "total cluster memory: #{redhat_cluster.aggregate_memory.to_i}")  if @debug
    $evm.log(:info, "available cluster memory: #{cluster_mem}") if @debug
    $evm.log(:info, "required vm memory: #{req_memory}") if @debug
    
    if cluster_mem < req_memory
      raise "Insufficient memory in cluster"
    end
    
    # Preset vars
    selected_host = nil
    sorted_hosts = []

    if redhat_cluster
      ## obtain a sorted list of hosts based on vm's
      sorted_hosts = redhat_cluster.hosts.sort { |a,b| a.v_total_vms <=> b.v_total_vms }
      
      ## Determine host to use by finding first host powered on in the list
      sorted_hosts.each { |host|
        #skip if power state is off
        if host.power_state == "on"
          #check if current memory headroom is greater than required.
          mem_available = host.current_memory_headroom.to_i
          req_mem = vm_memory.to_i + 25600 
          if mem_available > req_mem
            selected_host = host
            break 
          else
            $evm.log(:info, "Skipping host due to insufficient memory: [#{host.name}]") if @debug
          	next
          end	
        else
          $evm.log(:info, "Skipping host due to power state: [#{host.name}]") if @debug
          next
        end
      }
    end
    
    ## Set the selected host
    if selected_host
      rhev_host = "#{selected_host.id}"
      $evm.log(:info, "selected_host: #{selected_host.name} id: #{selected_host.id}") if @debug 
    end
    
  $evm.object['required'] = true
  $evm.object['value'] = rhev_host  
  end

  if selected_host.nil?
    raise "No Suitable Host Available"
  end
 
rescue => err
  $evm.object['value'] = "#{err}"
  $evm.log(:error, "ERROR: #{err.class}: #{err}")    
end 
