#
# Description: this method will set network_connection information, and infoblox info
#
begin
  
  @debug=$evm.root['debug']

  ## Set static vars
  domain = ".unionbank.com"
  tsm_suffix = "-tsm"
  nfs_suffix = "-nfs"
  network_info = []
  
  ## Obtain vars from root set by the dialog	
  vm_name = $evm.root['dialog_vm_name']
  primary_network_name = $evm.root['dialog_vlan']
  tsm_network_name = $evm.root['dialog_has_tsm'] || ""
  nfs_network_name = $evm.root['dialog_has_nfs'] || ""
  task = $evm.root['service_template_provision_task']
 
  ## Pass domain to root to be used by another method
  $evm.root['domain'] = domain
  
  ## Debug statements
  $evm.log(:info, "PROV_LOG_DEBUG- [domain] = #{domain}") if @debug
  $evm.log(:info, "PROV_LOG_DEBUG- [vm_name] = #{vm_name}") if @debug   
  $evm.log(:info, "PROV_LOG_DEBUG- [primary_network_name] = #{primary_network_name}") if @debug
  $evm.log(:info, "PROV_LOG_DEBUG- [tsm_network_name] = #{tsm_network_name}") if @debug
  $evm.log(:info, "PROV_LOG_DEBUG- [nfs_network_name] = #{nfs_network_name}") if @debug

  ## Set IP hash, used by infoblox, cobbler, and addNics
  ## Add the primary network
  network_info <<  { :fqdn => "#{vm_name}#{domain}", :network_name => "#{primary_network_name}", :adapter_name => "eth0" }
  $evm.log(:info, "PROV_LOG_DEBUG- network_info hash with primary_network = #{network_info.inspect}") if @debug
  
  ## Add the secondary networks
  if !tsm_network_name.empty? && !nfs_network_name.empty?
    $evm.log(:info, "PROV_LOG_DEBUG- has_tsm, has_nfs true") if @debug 
    network_info << { :fqdn => "#{vm_name}#{tsm_suffix}#{domain}", :network_name => "#{tsm_network_name}", :adapter_name => "eth1" }
    network_info << { :fqdn => "#{vm_name}#{nfs_suffix}#{domain}", :network_name => "#{nfs_network_name}", :adapter_name => "eth2" }
  elsif !tsm_network_name.empty? && nfs_network_name.empty?
    $evm.log(:info, "PROV_LOG_DEBUG- has_tsm true") if @debug 
    network_info << { :fqdn => "#{vm_name}#{tsm_suffix}#{domain}", :network_name => "#{tsm_network_name}", :adapter_name => "eth1" }
  elsif !nfs_network_name.empty? && tsm_network_name.empty?
    $evm.log(:info, "PROV_LOG_DEBUG- has_nfs true") if @debug 
    network_info << { :fqdn => "#{vm_name}#{nfs_suffix}#{domain}", :network_name => "#{nfs_network_name}", :adapter_name => "eth1" }
  end

  ## Pass the hash to dialog_options
  $evm.log(:info, "PROV_LOG- network_info hash is built: #{network_info.inspect}")
  task.set_dialog_option('dialog_network_info', network_info) 
  
  
rescue => err
  $evm.root['ae_result'] = 'error'
  $evm.root['ae_reason'] = "Caught exception in set_network_info:#{err.class}:#{err}"
  $evm.log('error', "#{$evm.root['ae_reason']}")
  #exit MIQ_ABORT
end 

