#
# Description: This method is executed when the provisioning request is NOT auto-approved
#

# Get objects
msg = $evm.object['reason']
$evm.log('info', "#{msg}")

# Raise automation event: request_pending
$evm.root["miq_request"].pending


###################################
#
# Method: emailapprover
#
# Build email to approver with reason
#
###################################
def emailapprover(miq_request,  msg, vm_name)
  $evm.log('info', "Approver email logic starting")
  
  # Get requester object
  requester = miq_request.requester

  # Get requester email else set to nil
  requester_email = requester.email || nil
  requester_name = requester.name || nil

  # Get Owner Email else set to nil
  owner_email = miq_request.options[:owner_email] || nil
  $evm.log('info', "Requester email:<#{requester_email}> Owner Email:<#{owner_email}>")

  # Override to email address below or get to_email_address from from model
  to = "haarika.bathineni@unionbank.com,jake.millette@unionbank.com,sindhu.halvi@unionbank.com"
  #to = "sindhu.halvi@unionbank.com"
  # Override from_email_address below or get from_email_address from model
  from = owner_email
  
  # Get signature from model unless specified below
  signature = "ESS-Enterprise Server Engineering(ESE) Team"

  # Set email subject
  subject = "Request ID #{miq_request.id} - Virtual machine request is pending for approval"
 
  # Build email body
  body = "Approver, "
  body += "<br>A request to provision VM:#{vm_name} received from #{requester_name} is pending."
  body += "<br><br>#{msg}."
  body += "<br><br>Please login to cloudforms (https://chcfepte211.unionbank.com) and approve the request."
  body += "<br><br> Thank you,"
  body += "<br> #{signature}"

  # Send email to approver
  $evm.log('info', "Sending email to <#{to}> from <#{from}> subject: <#{subject}>")
  $evm.execute(:send_email, to, from, subject, body)
end

# Get miq_request from root
miq_request = $evm.root['miq_request']
raise "miq_request missing" if miq_request.nil?
$evm.log('info', "Detected Request:<#{miq_request.id}> with Approval State:<#{miq_request.approval_state}>")

# Get incoming message or set it to default if nil
msg = miq_request.resource.message || "Request pending"

dialog = miq_request.options[:dialog]
  
#check if the request is from vm or host.
vm_name = dialog['dialog_vm_name'] || ''
  
if(vm_name == '')
  $evm.root["miq_request"].approve("admin", "Auto-Approved")
  exit MIQ_OK
end
 

# Email Approver
emailapprover(miq_request,  msg, vm_name)
