#
# Description: <Method description here>
#
begin
  #require 'uuidtools'

  def build_request(template_options, vm_options, tag_options, ws_options)
    user       = $evm.root['user']
    user_id    = user ? user.userid : "admin"
    user_email = user ? user.email : "jake.millette@unionbank.com"

    # Setup the parameter needed for request
    args = []
    # arg1 = version
    args << '1.1'
    # arg2 = templateFields
    args << template_options.collect { |k, v| "#{k}=#{v}" }.join('|')
    # arg3 = vmFields
    args << vm_options.collect { |k, v| "#{k}=#{v}" }.join('|')
    # arg4 = requester
    args << "user_name=#{user_id}|owner_email=#{user_email}"
    # arg5 = tags
    args << tag_options.collect { |k, v| "#{k}=#{v}" }.join('|')
    # arg6 = WS Values
    args << ws_options.collect { |k, v| "#{k}=#{v}" }.join('|')
    # arg7 = emsCustomAttributes
    args << nil
    # arg8 = miqCustomAttributes
    args << nil

    $evm.log("info", "#{@method} - Building provisioning request with the following arguments: <#{args.inspect}>")
#    $evm.execute('create_provision_request', *args)
  end

  
## MAIN ##################################################
  $evm.log("info", "Entering method #{@method}")
  @debug = true
  task = $evm.root['service_template_provision_task']
  if @debug
    $evm.log("info", "#{@method} - Listing Root Object Attributes:") 
    $evm.root.attributes.sort.each { |k, v| $evm.log("info", "#{@method} - \t#{k}: #{v}") }
    $evm.log("info", "#{@method} - ===========================================") 
    if task
      $evm.log("info", "#{@method} - Listing task Attributes:")
      task.attributes.sort.each { |k, v| $evm.log("info", "#{@method} - \t#{k}: #{v}")} 
      $evm.log("info", "#{@method} - ===========================================")
    end
  end

  # Set localized variables
  ## Variables collected through dialog
  ### Basic
  hostname         = $evm.object['dialog_hostname']
  os_type          = $evm.object['dialog_os_type']
  puppet_role      = $evm.object['dialog_puppet_role'] 
  
  ### Environment
  data_center      = $evm.object['dialog_dc_name']  
  cluster          = $evm.object['dialog_cluster_name'] 
  ### hardware
  memory_size      = $evm.object['dialog_vm_memory']
  cpus             = $evm.object['dialog_cores_per_socket']
  cpu_sockets      = $evm.object['dialog_number_of_sockets']
  ### Network
  vlan             = $evm.object['dialog_vlan']

  ## Static variables
  template_name = 'cf_vm_template'
  
  missing_fields = [
    'hostname', 'os_type', 'data_center', 'cluster', 'memory_size', 'cpus', 'cpu_sockets', 'vlan'
  ].collect do | key |  
    key unless eval(key)
  end.compact
  unless missing_fields.empty?
    $evm.log('error', "Missing required variables: [#{missing_fields}]")
    exit MIQ_ABORT
  end
  
  ##Sets the memory size to a number in MB
  memory_size = memory_size.to_i
  memory_reserve = 60
  
  ##Template options
  template_options = {}
#  template_options[:guid]         = template.guid
  template_options[:request_type] = 'template'

  ##VM options
  vm_options = {}
  vm_options[:provision_type]    = 'native_clone'
  vm_options[:vm_name]           = hostname
  vm_options[:vlan]              = vlan
  vm_options[:vm_memory]         = memory_size     
  vm_options[:memory_reserve]    = (memory_size * (memory_reserve.to_f / 100)).to_i
  vm_options[:number_of_sockets] = cpu_sockets
  vm_options[:cores_per_socket]  = cpus


  ##TAG_options
  tag_options = {}
  #tag_options[:availability_zone]      = availability_zone
  #tag_options[:network_location]       = network_location
  #tag_options[:role]                   = role
  #tag_options[:deployment_environment] = deployment_environment

  ##WS_OPTIONS
  ws_options = {}
#  ws_options[:data_center]                = data_center
#  ws_options[:deployment_environment]     = deployment_environment
#  ws_options[:physical_environment]       = physical_environment
#  ws_options[:availability_zone]          = availability_zone
#  ws_options[:network_location]           = network_location
#  ws_options[:network]                    = network
#  ws_options[:hostname]                   = hostname
#  ws_options[:role]                       = role
#  ws_options[:profile]                    = profile

  build_request(template_options, vm_options, tag_options, ws_options)
  exit MIQ_OK

rescue => err
  $evm.log("error", "Inline Method: <#{@log_prefix}> - [#{err}]\n#{err.backtrace.join("\n")}")
  exit MIQ_ABORT
end
